<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//hu_HU

$LANG=array();


$LANG['backup'][0]="SQL dumpolása"; 
$LANG['backup'][1]="XML kiírása"; 
$LANG['backup'][11]="Méret"; 
$LANG['backup'][13]="Megnézés/letöltés"; 
$LANG['backup'][16]="Biztos, hogy felül szeretné írni az adatbázist a fájl tartalmával"; 
$LANG['backup'][17]="Fájl törlése"; 
$LANG['backup'][18]="Adatbázis mentése"; 
$LANG['backup'][19]="Most"; 
$LANG['backup'][21]="A fájl már létezik."; 
$LANG['backup'][22]="A bájt nem található"; 
$LANG['backup'][23]="Mysql hiba"; 
$LANG['backup'][24]="Automatikus átirányítás"; 

$LANG['bookmark'][1]="könyvjelző"; 
$LANG['bookmark'][2]="Könyvjelző részleges betöltése."; 
$LANG['bookmark'][3]="Nem vettél fel könyvjelzőt"; 
$LANG['bookmark'][4]="Új könyvjelző"; 
$LANG['bookmark'][5]="Nyilvános könyvjelzők"; 
$LANG['bookmark'][6]="Általános nézet"; 

$LANG['buttons'][0]="Keresés"; 
$LANG['buttons'][2]="Elküld"; 
$LANG['buttons'][3]="Hozzárendel"; 
$LANG['buttons'][4]="Telepít"; 
$LANG['buttons'][5]="Telepítés törlése"; 
$LANG['buttons'][6]="Töröl"; 
$LANG['buttons'][7]="Mehet"; 
$LANG['buttons'][8]="Hozzáad"; 
$LANG['buttons'][9]="Kapcsolódás"; 
$LANG['buttons'][10]="Leválaszt"; 
$LANG['buttons'][11]="Következő"; 
$LANG['buttons'][12]="Előző"; 
$LANG['buttons'][13]="Vissza"; 
$LANG['buttons'][14]="Frissít"; 
$LANG['buttons'][15]="Időzít"; 
$LANG['buttons'][16]="Üres"; 
$LANG['buttons'][17]="Kijelölés megfordítása"; 
$LANG['buttons'][18]="Mindet kijelöl"; 
$LANG['buttons'][19]="Kijelölést megszüntet"; 
$LANG['buttons'][20]="Áthelyezés"; 
$LANG['buttons'][21]="Visszaállít"; 
$LANG['buttons'][22]="Törlés végleg"; 
$LANG['buttons'][23]="Megmutat"; 
$LANG['buttons'][24]="Mozgás felfelé"; 
$LANG['buttons'][25]="Mozgás lefelé"; 
$LANG['buttons'][27]="PDF export"; 
$LANG['buttons'][28]="SLK export"; 
$LANG['buttons'][29]="Mindent PDF-be"; 
$LANG['buttons'][30]="Mindent SLK-ba"; 
$LANG['buttons'][31]="Export"; 
$LANG['buttons'][32]="Vége"; 
$LANG['buttons'][33]="Kezdet"; 
$LANG['buttons'][34]="Mégsem"; 
$LANG['buttons'][37]="Importál"; 
$LANG['buttons'][38]="Felold"; 
$LANG['buttons'][39]="Cserél"; 
$LANG['buttons'][40]="Mindent mutat"; 
$LANG['buttons'][41]="Bekapcsol"; 
$LANG['buttons'][42]="Kikapcsol"; 
$LANG['buttons'][43]="Böngészés"; 
$LANG['buttons'][44]="CSV export megnézése"; 
$LANG['buttons'][45]="CSV-be ment mindent"; 
$LANG['buttons'][46]="Előtte"; 
$LANG['buttons'][47]="Utána"; 
$LANG['buttons'][48]="Áthelyez"; 
$LANG['buttons'][49]="Védett"; 
$LANG['buttons'][50]="Teszt"; 
$LANG['buttons'][51]="Mentés"; 
$LANG['buttons'][52]="Betölt"; 
$LANG['buttons'][53]="Tisztítás"; 
$LANG['buttons'][55]="Első"; 
$LANG['buttons'][56]="Utolsó"; 
$LANG['buttons'][57]="Végrehajt"; 
$LANG['buttons'][58]="Frissít"; 
$LANG['buttons'][59]="Szétválaszt"; 

$LANG['calendar'][0]="ÉÉÉÉ-HH-NN"; 
$LANG['calendar'][1]="NN-HH-ÉÉÉÉ"; 
$LANG['calendar'][2]="HH-NN-ÉÉÉÉ"; 

$LANG['calendarD'][0]="V"; 
$LANG['calendarD'][1]="H"; 
$LANG['calendarD'][2]="K"; 
$LANG['calendarD'][3]="Sze"; 
$LANG['calendarD'][4]="Cs"; 
$LANG['calendarD'][5]="P"; 
$LANG['calendarD'][6]="Szo"; 

$LANG['calendarDay'][0]="Vasárnap"; 
$LANG['calendarDay'][1]="Hétfő"; 
$LANG['calendarDay'][2]="Kedd"; 
$LANG['calendarDay'][3]="Szerda"; 
$LANG['calendarDay'][4]="Csütörtök"; 
$LANG['calendarDay'][5]="Péntek"; 
$LANG['calendarDay'][6]="Szombat"; 

$LANG['calendarM'][0]="Január"; 
$LANG['calendarM'][1]="Február"; 
$LANG['calendarM'][2]="Március"; 
$LANG['calendarM'][3]="Április"; 
$LANG['calendarM'][4]="Május"; 
$LANG['calendarM'][5]="Június"; 
$LANG['calendarM'][6]="Július"; 
$LANG['calendarM'][7]="Augusztus"; 
$LANG['calendarM'][8]="Szeptember"; 
$LANG['calendarM'][9]="Október"; 
$LANG['calendarM'][10]="November"; 
$LANG['calendarM'][11]="December"; 

$LANG['cartridges'][0]="Patron"; 
$LANG['cartridges'][7]="Nincs patron"; 
$LANG['cartridges'][9]="Nincs patron"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Tintasugaras"; 
$LANG['cartridges'][12]="Patron típus"; 
$LANG['cartridges'][13]="Új"; 
$LANG['cartridges'][14]="Használt"; 
$LANG['cartridges'][15]="Elhasznált"; 
$LANG['cartridges'][16]="Patron(ok)"; 
$LANG['cartridges'][20]="Új"; 
$LANG['cartridges'][21]="Használt"; 
$LANG['cartridges'][22]="Elhasznált"; 
$LANG['cartridges'][24]="Bevételezés dátuma"; 
$LANG['cartridges'][27]="Ebben"; 
$LANG['cartridges'][29]="Felhasználás vége"; 
$LANG['cartridges'][32]="Kompatibilis nyomtatók"; 
$LANG['cartridges'][33]="Használt patron"; 
$LANG['cartridges'][34]="Nincs szabad patron"; 
$LANG['cartridges'][35]="Használt patronok"; 
$LANG['cartridges'][37]="Szalag"; 
$LANG['cartridges'][39]="Nyomtató számláló"; 
$LANG['cartridges'][40]="Raktározási idő"; 
$LANG['cartridges'][41]="Használat ideje"; 
$LANG['cartridges'][42]="Nyomtatott lapok átlagos száma"; 

$LANG['central'][2]="Utolsó"; 
$LANG['central'][4]="Nincs esemény"; 
$LANG['central'][5]="Fel"; 
$LANG['central'][6]="Kilépés"; 
$LANG['central'][7]="Segítség"; 
$LANG['central'][8]="Kiegészítések"; 
$LANG['central'][9]="Folyamatban levő bejelentések"; 
$LANG['central'][10]="Új bejelentések"; 
$LANG['central'][12]="Személyes nézet"; 
$LANG['central'][13]="Globális nézet"; 
$LANG['central'][14]="Csoport nézet"; 
$LANG['central'][18]="Lezárandó bejelentéseid"; 
$LANG['central'][19]="Jóváhagyásra váró bejelentéseid"; 

$LANG['choice'][0]="Nem"; 
$LANG['choice'][1]="Igen"; 

$LANG['common'][0]="Név nélkül"; 
$LANG['common'][1]="Tételei"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Törölt tételek megjelenítése"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Gyártó"; 
$LANG['common'][6]="Sablon neve"; 
$LANG['common'][7]="Válassz sablont"; 
$LANG['common'][8]="Sablonok kezelése"; 
$LANG['common'][9]="Sablon hozzáadása"; 
$LANG['common'][10]="Technikai felelős"; 
$LANG['common'][11]="Egyszerű nézet"; 
$LANG['common'][12]="Karbantartás"; 
$LANG['common'][13]="Sablon"; 
$LANG['common'][14]="Sablonok"; 
$LANG['common'][15]="Hely"; 
$LANG['common'][16]="Név"; 
$LANG['common'][17]="Típus"; 
$LANG['common'][18]="Kapcsolattartó"; 
$LANG['common'][19]="Sorozatszám"; 
$LANG['common'][20]="Leltári szám"; 
$LANG['common'][21]="Kapcsolattartó száma"; 
$LANG['common'][22]="Modell"; 
$LANG['common'][23]="A művelet sikerült"; 
$LANG['common'][24]="Nincs elem kiválasztva, vagy rosszul definiált művelet"; 
$LANG['common'][25]="Megjegyzések"; 
$LANG['common'][26]="Utoljára frissítve"; 
$LANG['common'][27]="Dátum"; 
$LANG['common'][28]="Törölve"; 
$LANG['common'][29]="Bővítmények"; 
$LANG['common'][30]="Új elem"; 
$LANG['common'][31]="Üres sablon"; 
$LANG['common'][32]="Jellemzők"; 
$LANG['common'][33]="Összesen"; 
$LANG['common'][34]="Felhasználó"; 
$LANG['common'][35]="Csoport"; 
$LANG['common'][36]="Kategória"; 
$LANG['common'][37]="Szerző"; 
$LANG['common'][38]="Egyedivé tesz"; 
$LANG['common'][39]="Tétel sokszorosítása a kapcsolatai számával"; 
$LANG['common'][40]="Biztosan egyedivé kívánja tenni a tételt ?"; 
$LANG['common'][41]="E-mail riasztások"; 
$LANG['common'][42]="Mobil"; 
$LANG['common'][43]="Vezetéknév"; 
$LANG['common'][44]="Alapértelmezett érték"; 
$LANG['common'][45]="max MB"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Folyamatban"; 
$LANG['common'][48]="Keresztnév"; 
$LANG['common'][49]="Nincs"; 
$LANG['common'][50]="Biztosan törölhető ?"; 
$LANG['common'][51]="Teljes név"; 
$LANG['common'][52]="Kiszolgáló"; 
$LANG['common'][53]="Listázás"; 
$LANG['common'][54]="Nem található elem"; 
$LANG['common'][55]="Biztosan törli ezt az elemet ?"; 
$LANG['common'][56]="Standard felület"; 
$LANG['common'][57]="Cím"; 
$LANG['common'][58]="Maximum"; 
$LANG['common'][59]="Globális"; 
$LANG['common'][60]="Aktív"; 
$LANG['common'][61]="Ismeretlen hiba"; 
$LANG['common'][62]="Másik"; 
$LANG['common'][63]="Hiba(k)"; 
$LANG['common'][64]="Menedzser"; 
$LANG['common'][65]="Interfész"; 
$LANG['common'][66]="Összes"; 
$LANG['common'][67]="Egyebek"; 
$LANG['common'][68]="Fekvő"; 
$LANG['common'][69]="Portré"; 
$LANG['common'][70]="Elem sikeresen hozzáadva"; 
$LANG['common'][71]="Sikeresen hozzáadva"; 
$LANG['common'][72]="Elem törölve"; 
$LANG['common'][73]="Elem végleg törölve"; 
$LANG['common'][74]="Elem visszaállítva"; 
$LANG['common'][75]="Nincs jogosultság a rekurzívvá alakításhoz"; 
$LANG['common'][76]="Nyilvános"; 
$LANG['common'][77]="Privát"; 
$LANG['common'][78]="Publikál"; 
$LANG['common'][79]="Privatizál"; 
$LANG['common'][80]="Betöltés folyamatban..."; 
$LANG['common'][81]="Töröltek ne jelenjenek meg"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="Nincs jogosultságod a művelethez"; 
$LANG['common'][84]="Jelző módosítás letiltva. Kapcsolt elemeket találtam."; 
$LANG['common'][85]="Láthatóság módosítása az alegységekben"; 
$LANG['common'][86]="Nincs engedélyed a láthatósági jelző módosításához az alszervezetekben."; 
$LANG['common'][87]="Új kártya"; 
$LANG['common'][88]="Személyes"; 
$LANG['common'][89]="Nincs telepítve"; 
$LANG['common'][90]="Objektum"; 
$LANG['common'][91]="Nem lehet módosítani a tulajdonságot, a szülőtől öröklődött."; 
$LANG['common'][92]="Alternatív felhasználónév"; 
$LANG['common'][93]="Új alárendelt címsor"; 

$LANG['computers'][0]="Kötet"; 
$LANG['computers'][1]="Szabad hely százaléka"; 
$LANG['computers'][2]="Szabad terület"; 
$LANG['computers'][3]="Teljes méret"; 
$LANG['computers'][4]="Fájlrendszerek"; 
$LANG['computers'][5]="Csatolási pont"; 
$LANG['computers'][6]="Fizikai útvonal"; 
$LANG['computers'][7]="Új kötet"; 
$LANG['computers'][8]="Kötetek"; 
$LANG['computers'][9]="Operációs rendszer"; 
$LANG['computers'][10]="OP.rsz. szériaszám"; 
$LANG['computers'][11]="OP.rsz termékkód"; 
$LANG['computers'][14]="Hozzáadva"; 
$LANG['computers'][23]="RAM típusa"; 
$LANG['computers'][24]="RAM mérete"; 
$LANG['computers'][25]="HD méret"; 
$LANG['computers'][36]="HD-Típus"; 
$LANG['computers'][37]="Nincs kapcsolódó monitor."; 
$LANG['computers'][38]="Nincs kapcsolódó nyomtató"; 
$LANG['computers'][39]="Nyomtatók"; 
$LANG['computers'][40]="Monitor(ok)"; 
$LANG['computers'][46]="Perifériák"; 
$LANG['computers'][47]="Nincs kapcsolódó periféria"; 
$LANG['computers'][48]="A hely módosult. A kapcsolódó elemek is ugyanoda lettek mozgatva."; 
$LANG['computers'][49]="Kapcsolattartó módosult. A kapcsolódó tételek ugyanerre lettek frissítve."; 
$LANG['computers'][50]="Felhasználó vagy csoport frissült. A kapcsolódó tételek is megkapták az új értéket."; 
$LANG['computers'][51]="Frissít"; 
$LANG['computers'][52]="OS verzió"; 
$LANG['computers'][53]="Javítócsomag"; 
$LANG['computers'][54]="Nincs kapcsolódó készülék"; 
$LANG['computers'][55]="Telefon(ok)"; 
$LANG['computers'][56]="Státusz frissítve. A kapcsolódó elemek státusza is frissült."; 

$LANG['connect'][0]="Közvetlen kapcsolatok"; 
$LANG['connect'][1]="Nem kapcsolódik"; 
$LANG['connect'][15]="Következő elemek automatikus frissítése"; 
$LANG['connect'][16]="Figyelem !! A következő elemek nem egyeznek meg"; 

$LANG['consumables'][0]="Kellék"; 
$LANG['consumables'][1]="Raktárban"; 
$LANG['consumables'][2]="Hivatkozás"; 
$LANG['consumables'][7]="Nem találtam kelléket"; 
$LANG['consumables'][9]="Nincs kellék"; 
$LANG['consumables'][12]="Kellék típus"; 
$LANG['consumables'][13]="Új"; 
$LANG['consumables'][15]="Használt"; 
$LANG['consumables'][16]="Kellék(ek)"; 
$LANG['consumables'][20]="Új"; 
$LANG['consumables'][22]="Használva"; 
$LANG['consumables'][23]="Állapot"; 
$LANG['consumables'][26]="Használat dátuma"; 
$LANG['consumables'][32]="Kiad"; 
$LANG['consumables'][35]="Régi kellékek"; 
$LANG['consumables'][36]="Raktár helye"; 
$LANG['consumables'][37]="Vissza a raktárba"; 
$LANG['consumables'][38]="Riasztási küszöb"; 

$LANG['contract'][0]="Szerződés lejárt"; 
$LANG['contract'][1]="Szerződés megjegyzései óta"; 

$LANG['crontask'][0]="Ütemezett feladatok"; 
$LANG['crontask'][1]="Szinkronizálás OCS-ből"; 
$LANG['crontask'][2]="Riasztás tonerekre"; 
$LANG['crontask'][3]="Riasztás kellékekre"; 
$LANG['crontask'][4]="Riasztás lejárt licencekre"; 
$LANG['crontask'][5]="Riasztás szerződésekre"; 
$LANG['crontask'][6]="Riasztás pénzügyi információkra"; 
$LANG['crontask'][7]="Régi naplók törlése"; 
$LANG['crontask'][8]="Adatbázis optimalizáció"; 
$LANG['crontask'][9]="E-mail fogadás"; 
$LANG['crontask'][10]="MySQL replika ellenőrzése"; 
$LANG['crontask'][11]="Új frissítések ellenőrzése"; 
$LANG['crontask'][12]="Lejárt munkamenetek törlése"; 
$LANG['crontask'][13]="Generált grafikonok törlése"; 
$LANG['crontask'][14]="Bejelentések adminisztratív lezárása"; 
$LANG['crontask'][15]="Nincsenek megoldott bejelentések"; 
$LANG['crontask'][31]="Kikapcsolva"; 
$LANG['crontask'][32]="Időzített"; 
$LANG['crontask'][33]="Futó"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Futás üzemmódja"; 
$LANG['crontask'][37]="Futás gyakorisága"; 
$LANG['crontask'][38]="Futás periódusa"; 
$LANG['crontask'][39]="Fogadott e-mailek száma"; 
$LANG['crontask'][40]="Utolsó indítás"; 
$LANG['crontask'][41]="Következő futás"; 
$LANG['crontask'][42]="Amint lehetséges"; 
$LANG['crontask'][43]="Nincs várakozó feladat"; 
$LANG['crontask'][44]="Befejezett feladat, részleges feldolgozottság"; 
$LANG['crontask'][45]="Befejezett feladat, teljes feldolgozottság"; 
$LANG['crontask'][46]="Befejezett feladat, nincs teendő"; 
$LANG['crontask'][47]="Utolsó futás listája"; 
$LANG['crontask'][48]="Kezdet"; 
$LANG['crontask'][50]="Futások száma"; 
$LANG['crontask'][51]="Minimum idő"; 
$LANG['crontask'][52]="Maximum idő"; 
$LANG['crontask'][53]="Átlagos idő"; 
$LANG['crontask'][55]="Minimum idő"; 
$LANG['crontask'][56]="Maximum szám"; 
$LANG['crontask'][57]="Átlag mennyiség"; 
$LANG['crontask'][58]="Darabszám összesen"; 
$LANG['crontask'][59]="Átlag sebesség"; 
$LANG['crontask'][60]="Rendszeridő"; 
$LANG['crontask'][61]="Kikapcsolt bővítmény"; 
$LANG['crontask'][62]="Elemek"; 

$LANG['devices'][0]="Új alkatrész"; 
$LANG['devices'][1]="Merevlemez"; 
$LANG['devices'][2]="Grafikus vezérlő"; 
$LANG['devices'][3]="Hálózati kártya"; 
$LANG['devices'][4]="Processzor"; 
$LANG['devices'][5]="Alaplap"; 
$LANG['devices'][6]="RAM"; 
$LANG['devices'][7]="Hangkártya"; 
$LANG['devices'][19]="Meghajtók"; 
$LANG['devices'][20]="Vezérlők"; 
$LANG['devices'][21]="Egyéb perifériák"; 
$LANG['devices'][22]="Házak"; 
$LANG['devices'][23]="Tápegység"; 
$LANG['devices'][24]="alapértelmezés"; 
$LANG['devices'][25]="Alkatrész hozzáadása"; 
$LANG['devices'][26]="Alkatrész törlése"; 

$LANG['device_case'][0]="Méret"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Írhatóság"; 
$LANG['device_drive'][1]="Sebesség"; 

$LANG['device_hdd'][0]="fordulatszám"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Kapacitás"; 

$LANG['device_iface'][0]="Sebesség"; 
$LANG['device_iface'][2]="Mac cím"; 

$LANG['device_moboard'][0]="Chipkészlet"; 

$LANG['device_power'][0]="Feszültség"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekvencia"; 
$LANG['device_ram'][2]="Méret"; 

$LANG['document'][1]="Ellenőrző összeg (SHA1)"; 
$LANG['document'][2]="Fájl"; 
$LANG['document'][3]="Fejléc"; 
$LANG['document'][4]="MIME típus"; 
$LANG['document'][7]="Dokumentumfajták"; 
$LANG['document'][9]="Kiterjesztés"; 
$LANG['document'][10]="Ikon"; 
$LANG['document'][11]="Hitelesített letöltés"; 
$LANG['document'][15]="Letöltés"; 
$LANG['document'][16]="Új dokumentum"; 
$LANG['document'][18]="Dokumentum"; 
$LANG['document'][19]="Hivatkozott tételek"; 
$LANG['document'][21]="Kapcsolódó dokumentumok"; 
$LANG['document'][22]="Aktuális fájl"; 
$LANG['document'][23]="Túl nagy fájl."; 
$LANG['document'][24]="Sikeresen törölve"; 
$LANG['document'][25]="Sikertelen törlés"; 
$LANG['document'][26]="A fájl érvényes. A feltöltés sikerült."; 
$LANG['document'][27]="Támadási kísérlet, vagy túl nagy fájl. Az átmeneti fájl mozgatása sikertelen."; 
$LANG['document'][28]="Nincs kiválasztott fájl."; 
$LANG['document'][29]="Nem sikerült létrehozni a könyvtárat"; 
$LANG['document'][30]="Ellenőrizd a jogosultságokat"; 
$LANG['document'][31]="A könyvtár nem létezik"; 
$LANG['document'][32]="Ismeretlen fájltípus"; 
$LANG['document'][33]="Webhivatkozás"; 
$LANG['document'][34]="Könyvtár létrehozása"; 
$LANG['document'][35]="A feltöltési könyvtár nem létezik"; 
$LANG['document'][36]="Használj FTP-t"; 
$LANG['document'][37]="Nincs elérhetővé tett fájl"; 
$LANG['document'][38]="Nincs meg a fájl"; 
$LANG['document'][39]="A dokumentum mozgatása sikerült"; 
$LANG['document'][40]="A fájl mozgatása sikertelen"; 
$LANG['document'][41]="A dokumentum másolása sikerült"; 
$LANG['document'][42]="Létrehozta"; 
$LANG['document'][43]="Ismeretlen fájl"; 
$LANG['document'][44]="Érvénytelen fájlnév"; 
$LANG['document'][45]="Jogosulatlan fájlhozzáférés"; 
$LANG['document'][46]="Sikertelen fájlküldés (talán túl nagy)"; 
$LANG['document'][48]="Már létezik dokumentum ezzel a fájlnévvel"; 
$LANG['document'][49]="A fájl hibás (rossz ellenőrző összeg)"; 
$LANG['document'][50]="Csatolt elemek"; 

$LANG['entity'][0]="Szervezet"; 
$LANG['entity'][2]="Fő szervezet"; 
$LANG['entity'][3]="Szervezethez rendelés"; 
$LANG['entity'][5]="Automatikus számítógép hozzárendelés"; 
$LANG['entity'][6]="Automatikus felhasználó hozzárendelés"; 
$LANG['entity'][7]="fastruktúra"; 
$LANG['entity'][8]="Szervezetenként"; 
$LANG['entity'][9]="Alegységek"; 
$LANG['entity'][10]="Válassza ki a kívánt szervezetet"; 
$LANG['entity'][11]="a szervezet és alegységeinek megtekintéséhez"; 
$LANG['entity'][12]="Szervezet LDAP DN-je"; 
$LANG['entity'][13]="Szervezet címke (TAG)"; 
$LANG['entity'][14]="Bővebb információk"; 
$LANG['entity'][15]="A szervezet LDAP könyvtára"; 
$LANG['entity'][16]="Keresési szűrő (ha szükséges)"; 
$LANG['entity'][17]="Konfiguráció adminisztratív lezárása"; 
$LANG['entity'][18]="Bejelentések automatikus lezárásának napja"; 

$LANG['event'][0]="Forrás"; 
$LANG['event'][2]="Szerviz"; 
$LANG['event'][3]="Szint"; 
$LANG['event'][4]="Üzenet"; 
$LANG['event'][18]="Mező"; 
$LANG['event'][19]="Módosítás"; 
$LANG['event'][20]="Nincs történet"; 

$LANG['financial'][1]="Szerződés"; 
$LANG['financial'][2]="Élete"; 
$LANG['financial'][3]="Pénzügyi infók"; 
$LANG['financial'][4]="Szám"; 
$LANG['financial'][5]="Költség"; 
$LANG['financial'][6]="Szerződés típusa"; 
$LANG['financial'][8]="Tartam"; 
$LANG['financial'][9]="év"; 
$LANG['financial'][10]="Felmondási idő"; 
$LANG['financial'][11]="Számlázás gyakorisága"; 
$LANG['financial'][13]="Bizonylatszám"; 
$LANG['financial'][14]="Vásárlás dátuma"; 
$LANG['financial'][15]="Garancia hossza"; 
$LANG['financial'][16]="Garancia információk"; 
$LANG['financial'][18]="Rendelés száma"; 
$LANG['financial'][19]="Kézbesítési űrlap"; 
$LANG['financial'][20]="Szállítólevél száma"; 
$LANG['financial'][21]="Érték"; 
$LANG['financial'][22]="Leírás típusa"; 
$LANG['financial'][23]="Leírás ideje"; 
$LANG['financial'][24]="Új kapcsolat"; 
$LANG['financial'][25]="Új cég"; 
$LANG['financial'][26]="Cég"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Új kapcsolat"; 
$LANG['financial'][36]="Új szerződés"; 
$LANG['financial'][42]="Pénzügyi"; 
$LANG['financial'][43]="Technikus"; 
$LANG['financial'][44]="Cím"; 
$LANG['financial'][45]="Webhely"; 
$LANG['financial'][46]="Kapcsolódó kapcsolatok"; 
$LANG['financial'][47]="Lineáris"; 
$LANG['financial'][48]="Degresszív"; 
$LANG['financial'][50]="Kölcsön"; 
$LANG['financial'][51]="Bérlés"; 
$LANG['financial'][52]="Lízing"; 
$LANG['financial'][53]="Biztosítás"; 
$LANG['financial'][54]="Hardvertámogatás"; 
$LANG['financial'][55]="Szoftvertámogatás"; 
$LANG['financial'][56]="Szerviz szolgáltató"; 
$LANG['financial'][57]="hónap"; 
$LANG['financial'][59]="Beavatkozási idő"; 
$LANG['financial'][60]="Hétköznap"; 
$LANG['financial'][61]="Szombaton"; 
$LANG['financial'][62]="Vasár- és ünnepnapokon"; 
$LANG['financial'][65]="Kapcsolódó cégek"; 
$LANG['financial'][66]="Kapcsolódó szerződések"; 
$LANG['financial'][68]="Pénzügyi információk aktiválása"; 
$LANG['financial'][69]="Szerződés periódusa"; 
$LANG['financial'][76]="Kezdő dátum"; 
$LANG['financial'][77]="Leírási kulcs"; 
$LANG['financial'][78]="Garancia lejárati érték"; 
$LANG['financial'][79]="Partner típusa"; 
$LANG['financial'][80]="Garancia lejár"; 
$LANG['financial'][81]="Könyv szerinti (nettó) érték"; 
$LANG['financial'][82]="Számlaszám"; 
$LANG['financial'][83]="Tételek max száma (0=korlátlan)"; 
$LANG['financial'][84]="Ehhez az elemhez a pénzügyi infók csak minták azokhoz, amiket Te adsz hozzá"; 
$LANG['financial'][85]="A keresett tétel nem található"; 
$LANG['financial'][86]="Szerződés lejár"; 
$LANG['financial'][87]="Költségvetés"; 
$LANG['financial'][88]="Lejár:"; 
$LANG['financial'][89]="TCO (érték+követés költsége)"; 
$LANG['financial'][90]="Összes havi költség"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="30 napon belül lejárt szerződések"; 
$LANG['financial'][94]="7 napon belül lejáró szerződések"; 
$LANG['financial'][95]="30 napon belül lejáró szerződések"; 
$LANG['financial'][96]="Szerződések 7 napon belüli felmondással"; 
$LANG['financial'][97]="Szerződések 30 napon belüli felmondással"; 
$LANG['financial'][98]="Befejezés dátuma"; 
$LANG['financial'][99]="Befejezés dátuma + felmondás"; 
$LANG['financial'][100]="Irányítószám"; 
$LANG['financial'][101]="Város"; 
$LANG['financial'][102]="Állam"; 
$LANG['financial'][103]="Ország"; 
$LANG['financial'][104]="Hozzárendelt tételek"; 
$LANG['financial'][105]="Hallgatólagos"; 
$LANG['financial'][106]="Expressz"; 
$LANG['financial'][107]="Megújítás"; 
$LANG['financial'][108]="Összes kiadás"; 
$LANG['financial'][109]="Maradék összeg"; 
$LANG['financial'][110]="Költségvetések"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="óra"; 
$LANG['gmt'][2]="ó"; 

$LANG['help'][1]="Prioritás kalkulus mátrixa"; 
$LANG['help'][2]="Fő"; 
$LANG['help'][3]="Nagyon fontos"; 
$LANG['help'][4]="Fontos"; 
$LANG['help'][5]="Közepes"; 
$LANG['help'][6]="Kevésbé fontos"; 
$LANG['help'][7]="Nem fontos"; 
$LANG['help'][8]="Kérek jelzést az alábbi eseményekről"; 
$LANG['help'][11]="Az E-mail címem"; 
$LANG['help'][14]="Üzenet küldése"; 
$LANG['help'][16]="Ha értesítést szeretnél a műveletekről, add meg az e-mail címed!"; 
$LANG['help'][18]="Az üzenet elküldése sikerült, a kérés teljesítése folyamatban van."; 
$LANG['help'][19]="Köszönjük, hogy az automata ügyfélszolgálatot használtad."; 
$LANG['help'][22]="Számítógép keresése azonosító (ID) alapján"; 
$LANG['help'][23]="Írd be az első betűket (felhasználónév, tétel vagy sorozatszám)"; 
$LANG['help'][24]="Hardver fajtája"; 
$LANG['help'][25]="Számítógép"; 
$LANG['help'][26]="Hálózati eszköz"; 
$LANG['help'][27]="Nyomtató"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Eszköz"; 
$LANG['help'][30]="Általános"; 
$LANG['help'][31]="Szoftver"; 
$LANG['help'][35]="Telefonok"; 
$LANG['help'][40]="Nem adtál címet a bejelentésnek, próbáld újra."; 
$LANG['help'][41]="Nincs kategória beállítva, próbáld újra."; 
$LANG['help'][42]="Nagyon magas"; 
$LANG['help'][43]="Magas"; 
$LANG['help'][44]="Közepes"; 
$LANG['help'][45]="Alacsony"; 
$LANG['help'][46]="Nagyon alacsony"; 
$LANG['help'][47]="Nagyon magas"; 
$LANG['help'][48]="Magas"; 
$LANG['help'][49]="Közepes"; 
$LANG['help'][50]="Alacsony"; 
$LANG['help'][51]="Nagyon alacsony"; 

$LANG['install'][0]="GLPI telepítés vagy frissítés"; 
$LANG['install'][1]="Válassza az Install-t teljesen új GLPI telepítéshez"; 
$LANG['install'][2]="Válassza a Frissítés-t (Update) korábbi GLPI verzió frissítéséhez"; 
$LANG['install'][3]="Telepítés"; 
$LANG['install'][4]="Frissítés"; 
$LANG['install'][5]="Ellenőrzöm, hogy a GLPI kompatibilis-e a környezettel"; 
$LANG['install'][6]="Teszt kész"; 
$LANG['install'][7]="Eredmények"; 
$LANG['install'][8]="PHP tesztelése"; 
$LANG['install'][9]="Legalább PHP5-öt kell telepíteni."; 
$LANG['install'][10]="A GLPI nem kompatibilis a zend.ze1_compatibility_mode = On opcióval."; 
$LANG['install'][11]="PHP legalább 5.x- - Tökéletes !"; 
$LANG['install'][12]="Sessionok tesztelése"; 
$LANG['install'][13]="A PHP nem támogatja a munkameneteket !"; 
$LANG['install'][14]="Sessionok működnek - Tökéletes !"; 
$LANG['install'][15]="Ellenőrizze, hogy a sessionok támogatása be van-e kapcsolva a php.ini-ben"; 
$LANG['install'][16]="Mentések írhatóságának ellenőrzése"; 
$LANG['install'][17]="A fájlt nem sikerült létrehozni."; 
$LANG['install'][18]="Vannak további, nem hivatalos fordítások"; 
$LANG['install'][19]="A fájlt sikerült létrehozni de nem lehet törölni."; 
$LANG['install'][20]="A fájl törlése sikerült - Tökéletes !"; 
$LANG['install'][21]="Dokumentumok írhatóságának ellenőrzése"; 
$LANG['install'][22]="Fájlt sikerült létrehozni - Tökéletes !"; 
$LANG['install'][23]="Beállítások fájljainak írásellenőrzése"; 
$LANG['install'][24]="Az adatbázis inicializálása"; 
$LANG['install'][25]="Folytatás ?"; 
$LANG['install'][26]="Folytatás"; 
$LANG['install'][27]="Újra"; 
$LANG['install'][28]="Adatbázis kapcsolat beállítása"; 
$LANG['install'][29]="Adatbázis kapcsolódás paraméterei"; 
$LANG['install'][30]="Mysql kiszolgáló"; 
$LANG['install'][31]="Mysql felhasználó"; 
$LANG['install'][32]="Mysql jelszó"; 
$LANG['install'][34]="Adatbázis kapcsolat ellenőrzése"; 
$LANG['install'][35]="Nem lehet csatlakozni az adatbázishoz"; 
$LANG['install'][36]="A kiszolgáló válaszolt"; 
$LANG['install'][37]="A kiszolgáló címe vagy a felhasználónév mező üres"; 
$LANG['install'][38]="Válassz adatbázist:"; 
$LANG['install'][39]="Új adatbázis létrehozása vagy létező használata :"; 
$LANG['install'][40]="Válassza ki a frissítendő adatbázist:"; 
$LANG['install'][41]="Nem lehet használni a következő adatbázist:"; 
$LANG['install'][43]="OK - adatbázis inicializálása sikerült"; 
$LANG['install'][47]="Nem lehet írni az adatbázis beállításait tartalmazó fájlt"; 
$LANG['install'][48]="Hiba az adatbázis létrehozása közben !"; 
$LANG['install'][49]="Nem választott adatbázist !"; 
$LANG['install'][50]="Munkamenetek írhatóságának ellenőrzése"; 
$LANG['install'][52]="Ütemező (cron) írhatóságának ellenőrzése"; 
$LANG['install'][53]="Napló fájlok írásának tesztelése"; 
$LANG['install'][55]="A telepítés kész"; 
$LANG['install'][57]="Az alapértelmezett felhasználónevek/jelszavak:"; 
$LANG['install'][58]="glpi/glpi-vel az admin jogokhoz"; 
$LANG['install'][59]="tech/tech-el a technikus fiókhoz"; 
$LANG['install'][60]="normal-al a normál belépéshez"; 
$LANG['install'][61]="post-only/post-only a csak beküldő felhasználóhoz"; 
$LANG['install'][62]="Ezen felhasználók törölhetők."; 
$LANG['install'][64]="GLPI használata"; 
$LANG['install'][65]="magic_quotes_sybase bővítmény teszt"; 
$LANG['install'][66]="A GLPI nem működik megfelelően a magic_quotes_sybase beállítással; kérem kapcsolja ki majd próbálja újra"; 
$LANG['install'][67]="A magic_quotes_sybase opció nem aktív - Tökéletes !"; 
$LANG['install'][68]="Teszt munkamenet automatikus indítása"; 
$LANG['install'][69]="session.auto_start bekapcsolva. Nézd meg a .htaccess fájlt a GLPI gyökerében további útmutatáshoz"; 
$LANG['install'][70]="Nem lehet létrehozni az adatbázis-kapcsolati fájlt, ellenőrizd a fájlok hozzáférési jogait"; 
$LANG['install'][71]="Mysql bővítmény tesztelése"; 
$LANG['install'][72]="Mysql támogatás kell a php-be"; 
$LANG['install'][73]="Ok - mysql_connect() létezik - Tökéletes !"; 
$LANG['install'][74]="Session_use_trans_sid beállításának tesztelése"; 
$LANG['install'][75]="Ki kell kapcsolni a Session_use_trans_id option-t a php.ini-ben"; 
$LANG['install'][76]="Ok - a sessionok működnek - Tökéletes !"; 
$LANG['install'][77]="Lépés"; 
$LANG['install'][81]="Telepítés megkezdése"; 
$LANG['install'][82]="Adatbázis létrehozva"; 
$LANG['install'][85]="A függvények megvannak - Tökéletes !"; 
$LANG['install'][86]="Lefoglalt memória ellenőrzése"; 
$LANG['install'][87]="Lefoglalt memória"; 
$LANG['install'][88]="A GLPI-hez általában legalább 32M szükséges"; 
$LANG['install'][89]="Tökéletes !"; 
$LANG['install'][90]="Próbáld megnövelni a memory_limit paramétert a php.ini-ben."; 
$LANG['install'][91]="Lefoglalt memória > 64M"; 
$LANG['install'][92]="Licenc"; 
$LANG['install'][93]="Elolvastam és EGYETÉRTEK a licencfeltételekkel."; 
$LANG['install'][94]="Elolvastam és NEM ÉRTEK EGYET a licencfeltételekkel"; 
$LANG['install'][95]="Korlátlan memória"; 
$LANG['install'][96]="Korlátlan memória"; 
$LANG['install'][97]="Ellenőrizze, hogy a PHP tudja-e írni a következő könyvtárat:"; 
$LANG['install'][99]="Átmeneti fájlok írhatóságának ellenőrzése"; 
$LANG['install'][100]="A könyvtár létrehozása nem sikerült"; 
$LANG['install'][101]="A mappát létrehoztam de nem sikerült törölni"; 
$LANG['install'][102]="Json függvények tesztelése"; 
$LANG['install'][103]="A GLPI nem működik a json_encode és a json_decode függvények nélkül"; 
$LANG['install'][104]="mbstring bővítmény teszt"; 
$LANG['install'][105]="A PHP Mbstring bővítménye nincs telepítve"; 
$LANG['install'][106]="Grafikus fájlok írhatóságának ellenőrzése"; 

$LANG['job'][2]="rendező mező"; 
$LANG['job'][4]="Igénylő"; 
$LANG['job'][5]="Kiadva"; 
$LANG['job'][6]="Technikus"; 
$LANG['job'][7]="Feladat"; 
$LANG['job'][8]="utolsó bejelentés(ek)"; 
$LANG['job'][9]="Intézkedés"; 
$LANG['job'][11]="A probléma/művelet leírása"; 
$LANG['job'][12]="Nincs intézkedés a bejelentéshez"; 
$LANG['job'][13]="Új bejelentés"; 
$LANG['job'][15]="Megoldva"; 
$LANG['job'][19]="E-mail értesítések"; 
$LANG['job'][20]="Össz. idő"; 
$LANG['job'][21]="Óra(k)"; 
$LANG['job'][22]="Perc"; 
$LANG['job'][29]="Új intézkedés"; 
$LANG['job'][30]="Új feladat"; 
$LANG['job'][31]="Tartam"; 
$LANG['job'][32]="Nincs tervezve"; 
$LANG['job'][33]="Üres leírás"; 
$LANG['job'][34]="Intézkedés terve"; 
$LANG['job'][35]="Tervezés"; 
$LANG['job'][37]="Összesítés"; 
$LANG['job'][38]="Bejelentés"; 
$LANG['job'][39]="Intézkedés frissítése"; 
$LANG['job'][40]="Munkadíj"; 
$LANG['job'][41]="Fix költség"; 
$LANG['job'][42]="Anyagköltség"; 
$LANG['job'][43]="Összes költség"; 
$LANG['job'][44]="Kérés forrása"; 
$LANG['job'][45]="Intézkedés forrása"; 
$LANG['job'][46]="Bejelentés létrehozva"; 
$LANG['job'][47]="Költségek"; 
$LANG['job'][48]="Megoldás típusa"; 
$LANG['job'][49]="Új feladat"; 
$LANG['job'][50]="Nincs feladat a bejelentéshez"; 
$LANG['job'][51]="Megoldás elfogadása"; 
$LANG['job'][52]="Feladat módosítása"; 
$LANG['job'][53]="Feladat törlése"; 
$LANG['job'][54]="Ha nem válaszol, a bejelentés automatikusan le lesz zárva"; 

$LANG['joblist'][0]="Státusz"; 
$LANG['joblist'][1]="Csak a sajátokat"; 
$LANG['joblist'][2]="Prioritás"; 
$LANG['joblist'][3]="Sajátom/csoportomé"; 
$LANG['joblist'][4]="Kiadva"; 
$LANG['joblist'][6]="Leírás"; 
$LANG['joblist'][7]="Új bejelentés a tételhez"; 
$LANG['joblist'][8]="Nincs bejelentés."; 
$LANG['joblist'][9]="Új"; 
$LANG['joblist'][10]="Lezárva (megoldva)"; 
$LANG['joblist'][11]="megnyílt"; 
$LANG['joblist'][12]="Lezárva"; 
$LANG['joblist'][13]="Feldolgozandó bejelentések"; 
$LANG['joblist'][14]="Megoldva"; 
$LANG['joblist'][16]="Nincs folyamatban levő bejelentés."; 
$LANG['joblist'][17]="Lezárva (nincs megoldva)"; 
$LANG['joblist'][18]="Feldolgozás (kiadva)"; 
$LANG['joblist'][19]="Feldolgozás (tervezett)"; 
$LANG['joblist'][21]="Feldolgozás"; 
$LANG['joblist'][26]="Várakozó"; 
$LANG['joblist'][27]="E-mail nyomkövetéshez"; 
$LANG['joblist'][28]="Hivatkozott tételek bejelentései"; 
$LANG['joblist'][29]="Fontosság"; 
$LANG['joblist'][30]="Terhelés"; 
$LANG['joblist'][32]="Megoldva"; 
$LANG['joblist'][33]="Lezárt"; 
$LANG['joblist'][34]="Nincs megoldva"; 
$LANG['joblist'][35]="Nincs lezárva"; 
$LANG['joblist'][36]="Állapot érték az adatbázisban"; 

$LANG['jobresolution'][1]="Megoldás"; 
$LANG['jobresolution'][3]="Elfogadott megoldás"; 
$LANG['jobresolution'][4]="Visszautasított megoldás"; 
$LANG['jobresolution'][5]="Ha visszautasítja a megoldást, indokolnia kell"; 

$LANG['knowbase'][1]="GY.I.K."; 
$LANG['knowbase'][5]="Tétel kiállítása a nyilvános GY.I.K-ba"; 
$LANG['knowbase'][6]="Válassz kategóriát :"; 
$LANG['knowbase'][7]="Tétel törlése a nyilvános GY.I.K.-ből"; 
$LANG['knowbase'][8]="Tétel szerkesztése"; 
$LANG['knowbase'][9]="Tétel törlése"; 
$LANG['knowbase'][10]="Ez a tétel a nyilvános GY.I.K. része"; 
$LANG['knowbase'][11]="Ez a tétel nem része a publikus GY.I.K.-nek."; 
$LANG['knowbase'][12]="Kezdőmappa"; 
$LANG['knowbase'][13]="Kategória neve"; 
$LANG['knowbase'][14]="Tárgy"; 
$LANG['knowbase'][15]="Tartalom"; 
$LANG['knowbase'][24]="Hozzáférés a Gy.I.K.-hez"; 
$LANG['knowbase'][26]="Nézetek"; 
$LANG['knowbase'][27]="On"; 
$LANG['knowbase'][29]="Friss bejegyzések"; 
$LANG['knowbase'][30]="Legnépszerűbb kérdések"; 

$LANG['ldap'][0]="Felhasználók tömeges hozzáadása LDAP-ból"; 
$LANG['ldap'][1]="Már importált felhasználók szinkronizálása"; 
$LANG['ldap'][2]="Új felhasználók importálása"; 
$LANG['ldap'][3]="Nincs importálható felhasználó"; 
$LANG['ldap'][4]="LDAP könyvtár választása"; 
$LANG['ldap'][5]="Válassza ki az LDAP importálás forrását"; 
$LANG['ldap'][6]="Az LDAP könyvtárhoz kapcsolódás sikertelen"; 
$LANG['ldap'][7]="Nincs LDAP könyvtár definiálva"; 
$LANG['ldap'][8]="Figyelem: A kérés meghaladja a mappa limitjét. Az eredmények részlegesek lehetnek."; 
$LANG['ldap'][9]="LDAP kapcsolat tesztelése"; 
$LANG['ldap'][12]="Szinkronizálás"; 
$LANG['ldap'][13]="LDAP-ban"; 
$LANG['ldap'][14]="GLPI-ben"; 
$LANG['ldap'][15]="Szinkronizál"; 
$LANG['ldap'][16]="Elő-beállítás"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="LDAP replikák"; 
$LANG['ldap'][19]="Replikál"; 
$LANG['ldap'][20]="LDAP replika hozzáadás"; 
$LANG['ldap'][21]="Fő kiszolgáló"; 
$LANG['ldap'][22]="Replika(k)"; 
$LANG['ldap'][23]="Csoportok tömeges importja LDAP címtárból"; 
$LANG['ldap'][24]="Új csoportok importja"; 
$LANG['ldap'][25]="Nincs importálható csoport"; 
$LANG['ldap'][30]="LDAP álnevek kezelése"; 
$LANG['ldap'][31]="Soha nincs kikapcsolva a referencia (alapértelmezés)"; 
$LANG['ldap'][32]="Mindig hivatkozatlan"; 
$LANG['ldap'][33]="Hivatkozás törlése kereséskor"; 
$LANG['ldap'][34]="Hivatkozás törölve (nem a keresés alatt)"; 
$LANG['ldap'][35]="Felhasználó importálása"; 
$LANG['ldap'][36]="Nincs könyvtár rendelve a szervezethez : keresés nem lehetséges"; 
$LANG['ldap'][38]="Felhasználó keresési feltételek"; 
$LANG['ldap'][39]="Haladó"; 
$LANG['ldap'][40]="Egyszerű"; 
$LANG['ldap'][41]="Változtatni"; 
$LANG['ldap'][42]="Nincs kiválasztott könyvtár"; 
$LANG['ldap'][43]="Nincs szinkronizálandó felhasználó"; 
$LANG['ldap'][44]="Alapértelmezett szerver"; 
$LANG['ldap'][45]="Művelet könyvtárból törléskor"; 
$LANG['ldap'][46]="Akkreditációk és csoportok törlése"; 
$LANG['ldap'][47]="Áthelyezés kukába"; 
$LANG['ldap'][48]="LDAP-ban törölt felhasználó"; 
$LANG['ldap'][49]="Új felhasználók ekkortól"; 
$LANG['ldap'][50]="Frissített felhasználók ekkortól"; 
$LANG['ldap'][52]="Kevesebb mint"; 
$LANG['ldap'][53]="Több mint"; 
$LANG['ldap'][54]="Dátum szerinti szűrés bekapcsolása"; 
$LANG['ldap'][55]="Dátum szerinti szűrés kikapcsolása"; 
$LANG['ldap'][56]="Hetek"; 

$LANG['links'][1]="Hivatkozás vagy fájlnév"; 
$LANG['links'][4]="Hozzárendelt hardverfajta"; 
$LANG['links'][6]="Használható címkék"; 
$LANG['links'][7]="Nincs hivatkozás"; 
$LANG['links'][9]="Fájl tartalom"; 

$LANG['log'][1]="rendszer"; 
$LANG['log'][16]="tervezés"; 
$LANG['log'][18]="alkatrészek"; 
$LANG['log'][20]="tétel hozzáadva"; 
$LANG['log'][21]="tétel frissítése"; 
$LANG['log'][22]="tétel törlése"; 
$LANG['log'][23]="tétel visszaállítása"; 
$LANG['log'][24]="tétel végleges törlése"; 
$LANG['log'][26]="tétel lekapcsolása"; 
$LANG['log'][27]="tétel kapcsolata"; 
$LANG['log'][28]="alkatrészek frissítése"; 
$LANG['log'][29]="megoldás elfogadása/elutasítása"; 
$LANG['log'][30]="típust kapcsol"; 
$LANG['log'][31]="típus törlése"; 
$LANG['log'][32]="új hivatkozás eszközre"; 
$LANG['log'][33]="kapcsolat törlése"; 
$LANG['log'][34]="új hivatkozás vállalatra"; 
$LANG['log'][35]="céghivatkozás törlése"; 
$LANG['log'][40]="IP kapcsolat"; 
$LANG['log'][41]="kapcsolódás sikertelen"; 
$LANG['log'][42]="Foglalás"; 
$LANG['log'][44]="Fejléc"; 
$LANG['log'][45]="Sikeres"; 
$LANG['log'][46]="Sikertelen"; 
$LANG['log'][48]="felhasználó felvétele a csoportba"; 
$LANG['log'][49]="felhasználó törlése a csoportból"; 
$LANG['log'][55]="Kapcsolódás"; 
$LANG['log'][59]="Ütemező"; 
$LANG['log'][60]="Elem egyedivé tétele"; 
$LANG['log'][61]="felhasználó hozzáadása a szervezethez"; 
$LANG['log'][62]="felhasználó törlése a szervezetből"; 
$LANG['log'][64]="megjegyzések módosítása"; 
$LANG['log'][65]="szabály"; 
$LANG['log'][66]="Biztonság"; 
$LANG['log'][67]="megjegyzés módosítása"; 
$LANG['log'][70]="hálózati kapu hozzáadva"; 
$LANG['log'][71]="több új hálózati port hozzáadva"; 
$LANG['log'][73]="hálózati port törölve"; 
$LANG['log'][74]="Több hálózati port törölve"; 
$LANG['log'][75]="hálózati port áthelyezve"; 
$LANG['log'][77]="vlan hozzárendelve egy hálózati porthoz"; 
$LANG['log'][78]="vlan hozzárendelés több hálózati porthoz"; 
$LANG['log'][79]="vlan hozzárendelés törlése"; 
$LANG['log'][80]="vlan hozzárendelés törlése több portról"; 
$LANG['log'][82]="verzió hozzáadás"; 
$LANG['log'][83]="verzió módosítása"; 
$LANG['log'][84]="a verzió törlése"; 
$LANG['log'][85]="licenc hozzáadás"; 
$LANG['log'][86]="licenc módosítása"; 
$LANG['log'][87]="a licenc törlése"; 
$LANG['log'][88]="patron hozzáadás"; 
$LANG['log'][89]="fogyóeszközök hozzáadása"; 
$LANG['log'][90]="toner kivétele"; 
$LANG['log'][91]="kellék kivétele"; 
$LANG['log'][92]="toner visszaállítás"; 
$LANG['log'][93]="fogyóeszköz visszaállítás"; 
$LANG['log'][94]="patron frissítése"; 
$LANG['log'][95]="patron telepítése"; 
$LANG['log'][96]="patron eltávolítása"; 
$LANG['log'][97]="kellékanyag elfogyott"; 
$LANG['log'][98]="elem hozzáadása"; 
$LANG['log'][99]="elem módosítása"; 
$LANG['log'][100]="elem törlése"; 

$LANG['login'][0]="Utolsó kapcsolat"; 
$LANG['login'][1]="Belépés újra"; 
$LANG['login'][2]="LDAP"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Hozzáférés megtagadva"; 
$LANG['login'][6]="Belépés"; 
$LANG['login'][7]="Jelszó"; 
$LANG['login'][8]="Üres azonosító vagy jelszó"; 
$LANG['login'][9]="Nincs hitelesítve"; 
$LANG['login'][10]="Bejelentkezés"; 
$LANG['login'][11]="A felhasználó nem jelentkezhet be"; 
$LANG['login'][12]="Rossz felhasználónév vagy jelszó"; 
$LANG['login'][13]="A jelszó nem lehet üres"; 
$LANG['login'][14]="ismeretlen felhasználó"; 
$LANG['login'][15]="Nincs, vagy több ilyen nevű felhasználónév is van"; 
$LANG['login'][16]="sikertelen LDAP hitelesítés"; 
$LANG['login'][18]="GLPI belső alapja"; 
$LANG['login'][20]="Nem használhatod az alkalmazást, mert a felhasználóneved törölt, vagy inaktív"; 
$LANG['login'][21]="IMAP/POP kiszolgáló kapcsolat tesztelés"; 
$LANG['login'][22]="Az IMAP/POP kiszolgálóhoz kapcsolódás sikeres"; 
$LANG['login'][23]="Az IMAP/POP kiszolgálóhoz való kapcsolódás sikertelen"; 
$LANG['login'][24]="Utolsó módosítás dátuma"; 
$LANG['login'][25]="Nincs jog a kapcsolódáshoz"; 
$LANG['login'][26]="JavaScript engedélyezése szükséges a böngészőben"; 
$LANG['login'][27]="Engedélyezni kell a sütiket az alkalmazás használatához"; 
$LANG['login'][30]="Hitelesítési módszer módosítása"; 
$LANG['login'][31]="Hitelesítés könyvtárral"; 
$LANG['login'][32]="Hitelesítés GLPI adatbázissal"; 
$LANG['login'][33]="Hitelesítés IMAP/POP kiszolgálón"; 

$LANG['mailgate'][0]="E-mail érkeztető"; 
$LANG['mailgate'][2]="E-mail bejelentések letöltése"; 
$LANG['mailgate'][3]="Elérhető és letöltött e-mailek"; 
$LANG['mailgate'][4]="Az mbstring kiterjesztés hiányzik, kéretik figyelni a használt kódlapra."; 
$LANG['mailgate'][5]="Érvénytelen csatolt fájl"; 
$LANG['mailgate'][6]="Túl nagy csatolt fájl"; 
$LANG['mailgate'][7]="E-mail fogadó: csatolt fájl maximum mérete (0: nincs import)"; 
$LANG['mailgate'][9]="Az e-mail feldolgozása nem sikerült.\nHa a probléma továbbra is fennáll, fordulj az üzemeltetőhöz."; 
$LANG['mailgate'][10]="E-mail visszautasítva"; 
$LANG['mailgate'][11]="E-mail fogadás feldolgozása"; 
$LANG['mailgate'][12]="Nem sikerült az e-mailt szervezethez rendelni"; 
$LANG['mailgate'][13]="Visszautasítás oka"; 
$LANG['mailgate'][14]="Email nem található. Nem lehet importálni."; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Már kész intézkedések"; 
$LANG['mailing'][5]="Bejelentés leírása"; 
$LANG['mailing'][10]="Új bejelentések intézkedései"; 
$LANG['mailing'][12]="Bejelentés hozzárendelése"; 
$LANG['mailing'][14]="Kategória módosítása"; 
$LANG['mailing'][15]="Prioritás módosítása"; 
$LANG['mailing'][17]="Bejelentés tételeinek módosítása"; 
$LANG['mailing'][18]="Szerző módosítása"; 
$LANG['mailing'][19]="Új foglalás"; 
$LANG['mailing'][20]="Bejelentés csoportjának módosítása"; 
$LANG['mailing'][21]="Jegy forrásának változásai"; 
$LANG['mailing'][23]="Foglalás módosítása"; 
$LANG['mailing'][26]="Hozzáadott dokumentum:"; 
$LANG['mailing'][27]="Állapot módosítása"; 
$LANG['mailing'][29]="A foglalás megszakítva"; 
$LANG['mailing'][30]="Bejelentés frissítése"; 
$LANG['mailing'][31]="Ez egy teszt levél a levelezés működésének ellenőrzésére"; 
$LANG['mailing'][32]="Mail teszt"; 
$LANG['mailing'][33]="Kellékek riasztások"; 
$LANG['mailing'][35]="Kellékek riasztási küszöbértéke"; 
$LANG['mailing'][36]="Kellékek riasztásai"; 
$LANG['mailing'][37]="Felmondási időt elért szerződések"; 
$LANG['mailing'][39]="Szerződés riasztások"; 
$LANG['mailing'][40]="Lejáró garanciájú tételek:"; 
$LANG['mailing'][41]="Pénzügyi információk riasztása"; 
$LANG['mailing'][42]="Munkaidő költség változásai"; 
$LANG['mailing'][43]="Fix költségek változásai"; 
$LANG['mailing'][44]="Anyagköltség változásai"; 
$LANG['mailing'][45]="Bejelentés címének módosítása"; 
$LANG['mailing'][46]="Bejelentés szövegének módosítása"; 
$LANG['mailing'][47]="Hiba e-mail küldés közben"; 
$LANG['mailing'][48]="Nyitás dátumának módosítása"; 
$LANG['mailing'][49]="Változás a nyitó dátumban"; 
$LANG['mailing'][50]="Bejelentés fogadójának módosítása"; 
$LANG['mailing'][51]="Lejárt licenc:"; 
$LANG['mailing'][53]="Megoldás változtatása"; 
$LANG['mailing'][54]="Lejárat"; 
$LANG['mailing'][100]="Nincs definiált kategória"; 
$LANG['mailing'][101]="E-mail értesítés bekapcsolva"; 
$LANG['mailing'][102]="E-mail értesítés kikapcsolva"; 
$LANG['mailing'][104]="Intézkedés időtartama"; 
$LANG['mailing'][105]="Kiadatlan"; 
$LANG['mailing'][107]="Üres"; 
$LANG['mailing'][109]="Nincs csoport"; 
$LANG['mailing'][110]="Érvénytelen e-mail cím"; 
$LANG['mailing'][113]="Értesítési sablonok"; 
$LANG['mailing'][114]="Törzs"; 
$LANG['mailing'][115]="E-mail törzs"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="szöveg"; 
$LANG['mailing'][118]="E-mail"; 
$LANG['mailing'][119]="Előfordulás"; 
$LANG['mailing'][120]="Értesítési módszer"; 
$LANG['mailing'][121]="Címzettek"; 
$LANG['mailing'][122]="Kész feladatok"; 
$LANG['mailing'][123]="Megoldott bejelentés"; 
$LANG['mailing'][124]="Új fordítás hozzáadása"; 
$LANG['mailing'][125]="Alapértelmezett nyelv"; 
$LANG['mailing'][126]="Sablon fordítás"; 
$LANG['mailing'][127]="Bejelentés lezárása"; 
$LANG['mailing'][128]="hagyd üresen a mezőt HTML-ből generáláshoz"; 
$LANG['mailing'][129]="Bejelentés törlése"; 
$LANG['mailing'][130]="Feladó"; 
$LANG['mailing'][131]="Címzett"; 
$LANG['mailing'][132]="E-mail fejléc"; 
$LANG['mailing'][133]="E-mailek törlése"; 
$LANG['mailing'][134]="Intézkedés frissítése"; 
$LANG['mailing'][135]="Intézkedés törlése"; 
$LANG['mailing'][136]="Foglalás vége"; 
$LANG['mailing'][137]="Hardver felhasználó"; 
$LANG['mailing'][138]="Használható címkék listája"; 
$LANG['mailing'][139]="Címke"; 
$LANG['mailing'][140]="TAG"; 
$LANG['mailing'][141]="Intézkedések"; 
$LANG['mailing'][142]="Feladatok"; 
$LANG['mailing'][143]="Érvényesítések"; 
$LANG['mailing'][144]="Történet"; 
$LANG['mailing'][145]="Értékek listája"; 
$LANG['mailing'][146]="Egyedi érték"; 
$LANG['mailing'][147]="Lehetséges érték(ek)"; 

$LANG['Menu'][0]="Számítógépek"; 
$LANG['Menu'][1]="Hálózatok"; 
$LANG['Menu'][2]="Nyomtatók"; 
$LANG['Menu'][3]="Monitorok"; 
$LANG['Menu'][4]="Szoftverek"; 
$LANG['Menu'][5]="Nyomkövetés"; 
$LANG['Menu'][6]="Jelentések"; 
$LANG['Menu'][11]="Beállítások"; 
$LANG['Menu'][12]="Karbantartás"; 
$LANG['Menu'][13]="Statisztikák"; 
$LANG['Menu'][14]="Felhasználók"; 
$LANG['Menu'][15]="Adminisztráció"; 
$LANG['Menu'][16]="Eszközök"; 
$LANG['Menu'][17]="Foglalások"; 
$LANG['Menu'][18]="Eszközök"; 
$LANG['Menu'][19]="Tudásbázis"; 
$LANG['Menu'][20]="GYIK"; 
$LANG['Menu'][21]="Patronok"; 
$LANG['Menu'][22]="Kapcsolattartók"; 
$LANG['Menu'][23]="Cégek"; 
$LANG['Menu'][24]="Pénzügyi információk"; 
$LANG['Menu'][25]="Szerződések"; 
$LANG['Menu'][26]="Menedzsment"; 
$LANG['Menu'][27]="Dokumentumok"; 
$LANG['Menu'][28]="Állapotok"; 
$LANG['Menu'][29]="Tervezés"; 
$LANG['Menu'][30]="Naplók"; 
$LANG['Menu'][31]="Egyszerűsített felület"; 
$LANG['Menu'][32]="Kellékek"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefonok"; 
$LANG['Menu'][35]="Profilok"; 
$LANG['Menu'][36]="Csoportok"; 
$LANG['Menu'][37]="Szervezetek"; 
$LANG['Menu'][38]="Leltár"; 
$LANG['Menu'][39]="E-mail átjárók"; 
$LANG['Menu'][40]="Könyvjelzők"; 
$LANG['Menu'][41]="Jogok"; 

$LANG['monitors'][14]="Mikrofon"; 
$LANG['monitors'][15]="Hangszóró"; 
$LANG['monitors'][18]="Jelzők"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Méret"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Forgatás"; 

$LANG['networking'][4]="Hálózati csatlakozó"; 
$LANG['networking'][5]="RAM (MB)"; 
$LANG['networking'][6]="Hálózati port"; 
$LANG['networking'][13]="hálózati portot találtam"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Csatlakozik"; 
$LANG['networking'][19]="Új hálózati port"; 
$LANG['networking'][21]="Logikai szám"; 
$LANG['networking'][25]=""; 
$LANG['networking'][37]="hálózati portot találtam"; 
$LANG['networking'][44]="A port"; 
$LANG['networking'][46]="Több port hozzáadása"; 
$LANG['networking'][47]="Kezdet"; 
$LANG['networking'][48]="vége"; 
$LANG['networking'][51]="Fali csatlakozó"; 
$LANG['networking'][55]="VLAN-hoz rendelés"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Válassz MAC címet a listából vagy hozz létre egyet"; 
$LANG['networking'][58]="VLAN törlése"; 
$LANG['networking'][59]="Átjáró"; 
$LANG['networking'][60]="Maszk"; 
$LANG['networking'][61]="Alhálózat"; 

$LANG['ocsconfig'][1]="OCSNG adatbázis felhasználónév"; 
$LANG['ocsconfig'][2]="OCSweb gépnév"; 
$LANG['ocsconfig'][3]="Az OCSweb felhasználó jelszava"; 
$LANG['ocsconfig'][4]="Az OCS adatbázis neve"; 
$LANG['ocsconfig'][5]="Import lehetőségek"; 
$LANG['ocsconfig'][6]="Kihagyás ocs importból"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Kihagyja a következő címkéket (elválasztó : $, üresen hagy : minden)"; 
$LANG['ocsconfig'][10]="Globális import"; 
$LANG['ocsconfig'][11]="Nincs import"; 
$LANG['ocsconfig'][12]="Egyedi importálás"; 
$LANG['ocsconfig'][13]="Egyedi import: minden úgy lesz importálva, ahogy van"; 
$LANG['ocsconfig'][14]="Teljes import: minden importálva lesz globális kezeléssel."; 
$LANG['ocsconfig'][15]="Nincs import: a bővítmény nem fogja importálni ezeket az elemeket"; 
$LANG['ocsconfig'][16]="Alapértelmezett állapot"; 
$LANG['ocsconfig'][17]="Az import szűkítése a következőkkel (elválasztó $, ha üres, mindent behoz)"; 
$LANG['ocsconfig'][18]="Először ellenőrizze a duplikátumok kezelését az OCSNG-ben"; 
$LANG['ocsconfig'][19]="Egység importálás sorozatszámra"; 
$LANG['ocsconfig'][27]="Általános számítógép információk"; 
$LANG['ocsconfig'][36]="Modemek"; 
$LANG['ocsconfig'][37]="Portok"; 
$LANG['ocsconfig'][38]="Az OCS szoftver-kategóriáinak használata"; 
$LANG['ocsconfig'][39]="OCS címke"; 
$LANG['ocsconfig'][40]="Cron-al szinkronizálandó gépek száma"; 
$LANG['ocsconfig'][41]="Registry"; 
$LANG['ocsconfig'][43]="OCS Adminisztratív beállítások"; 
$LANG['ocsconfig'][48]="Működés kapcsolat bontásakor"; 
$LANG['ocsconfig'][49]="Kuka"; 
$LANG['ocsconfig'][50]="Törlés"; 
$LANG['ocsconfig'][52]="Számítógépek automatikus kapcsolása"; 
$LANG['ocsconfig'][53]="Automatikus hivatkozás aktiválása"; 
$LANG['ocsconfig'][54]="Számítógép létezésének kritériuma"; 
$LANG['ocsconfig'][55]="A következő állapotú számítógépek keresése"; 
$LANG['ocsconfig'][56]="üres"; 
$LANG['ocsconfig'][57]="egyenlő"; 
$LANG['ocsconfig'][58]="A kapcsolat automatikusan párosítja az itt található gépeket az OCS tartalmával. Csak automatikus (szkripttel megvalósított) szinkronizáció esetén van jelentősége."; 
$LANG['ocsconfig'][59]="OCS felület címe"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Már importált gépek szinkronizálása"; 
$LANG['ocsng'][2]="Új gépek importálása"; 
$LANG['ocsng'][3]="GLPI-OCS hivatkozások törlése"; 
$LANG['ocsng'][4]="Új gépek csatolása meglévőkhöz"; 
$LANG['ocsng'][5]="Új gépeket importál"; 
$LANG['ocsng'][6]="Automata frissítés"; 
$LANG['ocsng'][7]="OCSNG-ből importálva"; 
$LANG['ocsng'][8]="Az importálás sikerült"; 
$LANG['ocsng'][9]="Nincs új importálandó gép"; 
$LANG['ocsng'][10]="OCS-ben frissült számítógépek"; 
$LANG['ocsng'][11]="Számítógépek frissítése"; 
$LANG['ocsng'][12]="Nincs frissítendő új gép"; 
$LANG['ocsng'][13]="GLPI-be importálás dátuma"; 
$LANG['ocsng'][14]="Utolsó frissítés az OCS-ben"; 
$LANG['ocsng'][15]="Nincs zárolt mező"; 
$LANG['ocsng'][16]="Zárolt mezők"; 
$LANG['ocsng'][18]="A kapcsolódás az OCS adatbázishoz sikerült"; 
$LANG['ocsng'][19]="Érvényes OCS NG verzió"; 
$LANG['ocsng'][20]="Érvénytelen OCS NG verzió: RC3 szükséges"; 
$LANG['ocsng'][21]="Az OCS-hez kapcsolódás sikertelen"; 
$LANG['ocsng'][22]="Figyelem! Az importált adatok felül fogják írni a jelenlegieket"; 
$LANG['ocsng'][23]="Sikertelen import, a GLPI gép már kapcsolódik egy OCS NG-ben levőhöz"; 
$LANG['ocsng'][24]="Szinkronizálás erőltetése"; 
$LANG['ocsng'][26]="OCS szerver választás"; 
$LANG['ocsng'][27]="Nincs OCS szerver megadva"; 
$LANG['ocsng'][29]="OCSNG kiszolgáló"; 
$LANG['ocsng'][30]="Zárolt monitorok"; 
$LANG['ocsng'][32]="Zárolt eszközök"; 
$LANG['ocsng'][34]="Zárolt nyomtatók"; 
$LANG['ocsng'][36]="Cél szervezet"; 
$LANG['ocsng'][37]="Előnézet bekapcsolása"; 
$LANG['ocsng'][38]="Előnézet kikapcsolása"; 
$LANG['ocsng'][40]="Illeszkedik a szabály ?"; 
$LANG['ocsng'][41]="Manuális import mód"; 
$LANG['ocsng'][42]="Érvénytelen OCS konfiguráció (TRACE_DELETED kapcsolónak aktívnak kell lennie)"; 
$LANG['ocsng'][43]="Hozzáférés megtagadva az OCS adatbázishoz (írási jog szükséges a hardware.CHECKSUM mezőhöz)"; 
$LANG['ocsng'][44]="Hozzáférés megtagadva az OCS adatbázishoz (a deleted_equiv táblához törlési jog szükséges)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="OCS-ban törölve"; 
$LANG['ocsng'][47]="Egy OCS géphez kapcsolva"; 
$LANG['ocsng'][48]="A számítógép OCS azonosítója megváltozott"; 
$LANG['ocsng'][49]="Ügynök"; 
$LANG['ocsng'][50]="Zárolt IP-k"; 
$LANG['ocsng'][52]="Zárolt szoftver(ek)"; 
$LANG['ocsng'][54]="OCS szinkron törölte a szoftvert"; 
$LANG['ocsng'][55]="Zárolt kötet(ek)"; 
$LANG['ocsng'][56]="Locked component(s)"; 
$LANG['ocsng'][57]="OCSNG interfész"; 

$LANG['pager'][1]="vége"; 
$LANG['pager'][2]="kezdet"; 
$LANG['pager'][3]="összesen"; 
$LANG['pager'][4]="Megjelenít"; 
$LANG['pager'][5]="tételt"; 

$LANG['peripherals'][18]="Márka"; 
$LANG['peripherals'][31]="Globális kezelés"; 
$LANG['peripherals'][32]="Egyedi kezelés"; 
$LANG['peripherals'][33]="Kezelés típusa"; 

$LANG['phones'][18]="Márka"; 
$LANG['phones'][36]="Tápegység"; 
$LANG['phones'][38]="Fejhallgatós telefon"; 
$LANG['phones'][39]="Hangszóró"; 
$LANG['phones'][40]="Sorok száma"; 

$LANG['planning'][0]="A kért technikus foglalt a kért időben."; 
$LANG['planning'][1]="Hiba a dátumokban."; 
$LANG['planning'][5]="Nap"; 
$LANG['planning'][6]="Hét"; 
$LANG['planning'][8]="Nyomkövetés"; 
$LANG['planning'][9]="Felelős"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Naptár letöltése iCal formátumban"; 
$LANG['planning'][13]="Webcal szinkronizálás"; 
$LANG['planning'][14]="Hónap"; 
$LANG['planning'][15]="Terveid"; 
$LANG['planning'][16]="Információ"; 
$LANG['planning'][17]="Tennivaló"; 
$LANG['planning'][18]="Kész"; 

$LANG['plugins'][0]="Bővítmények listája"; 
$LANG['plugins'][2]="Telepítve / nincs beállítva"; 
$LANG['plugins'][3]="Telepítve / nincs aktiválva"; 
$LANG['plugins'][4]="Hiba / törlésnél"; 
$LANG['plugins'][5]="Nincs funkció"; 
$LANG['plugins'][6]="Frissíteni"; 
$LANG['plugins'][7]="Nincsenek telepített bővítmények"; 
$LANG['plugins'][8]="Bővítmények katalógusának megtekintése"; 
$LANG['plugins'][9]="Szerzők"; 
$LANG['plugins'][10]="Inkompatibilis plugin"; 

$LANG['printers'][14]="Soros interfész"; 
$LANG['printers'][15]="Párhuzamos interfész"; 
$LANG['printers'][18]="Portok"; 
$LANG['printers'][27]="USB port"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Kezdeti oldalszámláló"; 
$LANG['printers'][31]="Nyomtatott lapok"; 

$LANG['profiles'][0]="Globális jog"; 
$LANG['profiles'][1]="Szervezeti jog"; 
$LANG['profiles'][2]="A profil felülete"; 
$LANG['profiles'][4]="Intézkedés a csoportom bejelentéseihez"; 
$LANG['profiles'][5]="Bejelentés létrehozása"; 
$LANG['profiles'][6]="Intézkedés hozzáadása saját bejelentéshez"; 
$LANG['profiles'][7]="Bejelentések megnézése"; 
$LANG['profiles'][8]="Minden intézkedés megnézése (nyilvános és privát)"; 
$LANG['profiles'][9]="Nyilvános intézkedések mutatása"; 
$LANG['profiles'][10]="Olvas"; 
$LANG['profiles'][11]="Ír"; 
$LANG['profiles'][12]="Nincs hozzáférés"; 
$LANG['profiles'][13]="Alapértelmezett profil"; 
$LANG['profiles'][14]="Bejelentés törlése"; 
$LANG['profiles'][15]="Intézkedés minden bejelentéshez"; 
$LANG['profiles'][16]="Bejelentés átvétele"; 
$LANG['profiles'][17]="Bejelentés eltulajdonítása"; 
$LANG['profiles'][18]="Bejelentés frissítése"; 
$LANG['profiles'][19]="Bejelentés hozzárendelése"; 
$LANG['profiles'][20]="Tervei megnézése"; 
$LANG['profiles'][21]="Minden terv megnézése"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Foglalás adminisztráció"; 
$LANG['profiles'][24]="Jelszó frissítése"; 
$LANG['profiles'][26]="A saját csoport bejelentéseinek megnézése"; 
$LANG['profiles'][27]="A csoport eszközeinek megjelenítése"; 
$LANG['profiles'][28]="Rekurzív"; 
$LANG['profiles'][29]="Dinamikus"; 
$LANG['profiles'][30]="OCSNG információk megtekintése"; 
$LANG['profiles'][31]="OCS szinkronizálás kézzel"; 
$LANG['profiles'][32]="Hozzám/csoportomhoz tartozó bejelentések megnézése"; 
$LANG['profiles'][33]="Nincs felhasználó"; 
$LANG['profiles'][34]="Felirat"; 
$LANG['profiles'][35]="Minden intézkedés frissítése"; 
$LANG['profiles'][36]="A csoportom tagjai időbeosztásának megtekintése"; 
$LANG['profiles'][37]="Alapértelmezett szervezet"; 
$LANG['profiles'][38]="Láthatóság"; 
$LANG['profiles'][39]="Hozzárendelés"; 
$LANG['profiles'][40]="Frissít"; 
$LANG['profiles'][41]="Létrehozás"; 
$LANG['profiles'][42]="Hozzárendelés"; 
$LANG['profiles'][43]="Felhasználók hitelesítésének és szinkronizálásának módja"; 
$LANG['profiles'][44]="Prioritás módosítása"; 
$LANG['profiles'][45]="Feladat hozzáadása minden bejelentéshez"; 
$LANG['profiles'][46]="Minden feladat szerkesztése"; 
$LANG['profiles'][47]="Felhasználók hozzáadása külső forrásból"; 
$LANG['profiles'][48]="Érvényesítési kérelem létrehozása"; 
$LANG['profiles'][49]="Bejelentés érvényesítése"; 

$LANG['registry'][1]="Gyűjtő"; 
$LANG['registry'][2]="Útvonal"; 
$LANG['registry'][3]="Kulcs/érték"; 
$LANG['registry'][4]="Regisztrációs kulcsok"; 
$LANG['registry'][5]="Nem található regisztrációs kulcs"; 
$LANG['registry'][6]="OCSNG gépnév"; 

$LANG['reminder'][0]="Személyes jegyzetek"; 
$LANG['reminder'][1]="Nyilvános jegyzetek"; 
$LANG['reminder'][6]="Új jegyzet"; 
$LANG['reminder'][9]="Szöveg"; 
$LANG['reminder'][12]="Hozzáadás a naptárhoz"; 
$LANG['reminder'][15]="Cím nélkül"; 
$LANG['reminder'][16]="Globális megjegyzések"; 

$LANG['reports'][0]="Válassz jelentéstípust"; 
$LANG['reports'][4]="Szerződéses hardverek"; 
$LANG['reports'][11]="Szerződés hatálya alatti hardverek"; 
$LANG['reports'][12]="Hardvertípus"; 
$LANG['reports'][13]="Dátum(ok)"; 
$LANG['reports'][15]="Jelentés mutatása"; 
$LANG['reports'][19]="Kapcsolattartó neve"; 
$LANG['reports'][26]="Alapértelmezett jelentés"; 
$LANG['reports'][27]="Szerződésenként"; 
$LANG['reports'][28]="Évenként"; 
$LANG['reports'][33]="Hálózati jelentés"; 
$LANG['reports'][36]="Kapcsolódó eszközök"; 
$LANG['reports'][37]="Fali csatlakozók"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Helyenként"; 
$LANG['reports'][41]="Hardverenként"; 
$LANG['reports'][42]="Fali csatlakozónként"; 
$LANG['reports'][46]="hardver portok"; 
$LANG['reports'][47]="eszköz portjai"; 
$LANG['reports'][49]="Hálózati jelentés kapcsolónként"; 
$LANG['reports'][51]="Hálózati jelentés fali csatlakozónként"; 
$LANG['reports'][52]="kapcsoló"; 
$LANG['reports'][54]="Hálózati jelentés helyenként"; 
$LANG['reports'][57]="Anyaglista"; 
$LANG['reports'][58]="Évenkénti leltárjelentés"; 
$LANG['reports'][60]="Nyitás dátuma"; 
$LANG['reports'][61]="Befejezés dátuma"; 
$LANG['reports'][62]="Hardverek pénzügyi információi"; 
$LANG['reports'][63]="Egyebek pénzügyi adatai (licencek, patronok, kellékek)"; 
$LANG['reports'][64]="Megoldás dátuma"; 

$LANG['reservation'][1]="Foglalható tételek"; 
$LANG['reservation'][2]="Eszköz átmenetileg nem érhető el"; 
$LANG['reservation'][3]="Érvénytelenít"; 
$LANG['reservation'][5]="Elérhetővé tétel"; 
$LANG['reservation'][6]="Nem kölcsönözhető"; 
$LANG['reservation'][7]="Kölcsönözhető"; 
$LANG['reservation'][8]="Foglal"; 
$LANG['reservation'][9]="Tételt foglal"; 
$LANG['reservation'][16]="vége"; 
$LANG['reservation'][17]="Kezdet"; 
$LANG['reservation'][18]="A kért tétel már foglalt erre az időre."; 
$LANG['reservation'][20]="Vissza a naptárhoz"; 
$LANG['reservation'][21]="Foglalások megnézése"; 
$LANG['reservation'][22]="Megjegyzés módosítása"; 
$LANG['reservation'][25]="Minden bérelhető hardver"; 
$LANG['reservation'][27]="Periódus"; 
$LANG['reservation'][28]="Hetente"; 
$LANG['reservation'][29]="Naponta"; 
$LANG['reservation'][30]="alkalommal"; 
$LANG['reservation'][31]="Rendezze"; 
$LANG['reservation'][35]="Jövőbeni és jelenlegi foglalások"; 
$LANG['reservation'][36]="Korábbi foglalások"; 
$LANG['reservation'][37]="Nincs foglalás"; 
$LANG['reservation'][38]="Biztos, hogy törölhető a tétel a kölcsönzésekből ?"; 
$LANG['reservation'][39]="Ezzel minden folyamatban levő foglalás törölve lesz."; 
$LANG['reservation'][40]="Ma lejáró eszköz foglalások"; 

$LANG['rulesengine'][0]="is"; 
$LANG['rulesengine'][1]="nem"; 
$LANG['rulesengine'][2]="tartalmaz"; 
$LANG['rulesengine'][3]="nem tartalmaz"; 
$LANG['rulesengine'][4]="kezdődik"; 
$LANG['rulesengine'][5]="befejezte"; 
$LANG['rulesengine'][6]="Kritérium"; 
$LANG['rulesengine'][7]="Műveletek"; 
$LANG['rulesengine'][8]="Jogosultságkezelés"; 
$LANG['rulesengine'][9]="Logikai művelet"; 
$LANG['rulesengine'][10]="Pozíció"; 
$LANG['rulesengine'][11]="Művelet típusa"; 
$LANG['rulesengine'][12]="Mezők"; 
$LANG['rulesengine'][13]="Érték"; 
$LANG['rulesengine'][14]="Feltétel"; 
$LANG['rulesengine'][15]="Ok"; 
$LANG['rulesengine'][16]="Kritérium"; 
$LANG['rulesengine'][17]="Szabályok"; 
$LANG['rulesengine'][18]="Számítógép céghez rendelésének szabályai"; 
$LANG['rulesengine'][19]="Szervezetek és jogok összerendelése"; 
$LANG['rulesengine'][20]="Alkalmazott szabályok"; 
$LANG['rulesengine'][21]="Alszervezetek szabályai"; 
$LANG['rulesengine'][22]="Hozzárendel"; 
$LANG['rulesengine'][23]="Helyi szabályok"; 
$LANG['rulesengine'][24]="Szabály típusa"; 
$LANG['rulesengine'][25]="Számítógép neve"; 
$LANG['rulesengine'][26]="Regex ellenőrzések"; 
$LANG['rulesengine'][27]="regex nem illeszkedik"; 
$LANG['rulesengine'][28]="Bejelentések üzleti szabályai"; 
$LANG['rulesengine'][29]="Szabályok listája"; 
$LANG['rulesengine'][30]="Művelet"; 
$LANG['rulesengine'][33]="Legördülő szótár"; 
$LANG['rulesengine'][35]="Szoftver szótár"; 
$LANG['rulesengine'][36]="Gyártó szótár"; 
$LANG['rulesengine'][37]="Szoftverek kategóriákhoz rendelésének szabályai"; 
$LANG['rulesengine'][38]="Újraszámol"; 
$LANG['rulesengine'][40]="a kategória"; 
$LANG['rulesengine'][41]="Érvényesítés"; 
$LANG['rulesengine'][42]="ÉS"; 
$LANG['rulesengine'][43]="VAGY"; 
$LANG['rulesengine'][45]="Érték hozzárendelés reguláris kifejezésből"; 
$LANG['rulesengine'][46]="Felszerelés IP címének hozzárendelése"; 
$LANG['rulesengine'][47]="Felszerelés név+domain hozzárendelés"; 
$LANG['rulesengine'][48]="Felszerelés hozzárendelése"; 
$LANG['rulesengine'][49]="Felszerelés MAC címének hozzárendelése"; 
$LANG['rulesengine'][50]="Számítógép modell szótár"; 
$LANG['rulesengine'][51]="Monitor modell szótár"; 
$LANG['rulesengine'][52]="Telefon modell szótár"; 
$LANG['rulesengine'][53]="Periféria modell szótár"; 
$LANG['rulesengine'][54]="Nyomtató modell szótár"; 
$LANG['rulesengine'][55]="Hálózati modell szótár"; 
$LANG['rulesengine'][56]="Modellek"; 
$LANG['rulesengine'][60]="Számítógép típus szótár"; 
$LANG['rulesengine'][61]="Monitor típus szótár"; 
$LANG['rulesengine'][62]="Telefon típus szótár"; 
$LANG['rulesengine'][63]="Periféria típus szótár"; 
$LANG['rulesengine'][64]="Nyomtató típus szótár"; 
$LANG['rulesengine'][65]="Hálózati eszköz típus szótár"; 
$LANG['rulesengine'][66]="Típusok"; 
$LANG['rulesengine'][67]="Op. rsz. szótár"; 
$LANG['rulesengine'][68]="Szervizcsomag szótár"; 
$LANG['rulesengine'][69]="Op rendszer szótár"; 
$LANG['rulesengine'][70]="E-mail bejelentések szervezethez rendelésének szabályai"; 
$LANG['rulesengine'][76]="Szótár visszafelé"; 
$LANG['rulesengine'][77]="Szótárak"; 
$LANG['rulesengine'][78]="Verzió"; 
$LANG['rulesengine'][79]="Reguláris eredmény hozzáadása"; 
$LANG['rulesengine'][80]="Globális szótár"; 
$LANG['rulesengine'][81]="Szabály eredménye"; 
$LANG['rulesengine'][82]="Eredmény részletei"; 
$LANG['rulesengine'][83]="A következő stringgel módosítható a reguláris kifejezés eredménye"; 
$LANG['rulesengine'][84]="Szabálymotor tesztelése"; 
$LANG['rulesengine'][85]="Reguláris kifejezés eredménye"; 
$LANG['rulesengine'][86]="Szótár törlése esetén érintett szoftverkategóriák"; 
$LANG['rulesengine'][87]="GLPI szótárral törölt szoftver"; 
$LANG['rulesengine'][90]="Feldolgozás folyamatban..."; 
$LANG['rulesengine'][91]="Munka befejezve."; 
$LANG['rulesengine'][92]="Figyelmeztetés a szótár futása előtt"; 
$LANG['rulesengine'][93]="Figyelem ! Ez a művelet szoftvereket tehet a lomtárba."; 
$LANG['rulesengine'][94]="EGYESÍT"; 
$LANG['rulesengine'][95]="Gyártó választás"; 
$LANG['rulesengine'][96]="Szótár visszafelé a következő gyártókra <br> ( ----- = ÖSSZES)"; 
$LANG['rulesengine'][97]="Nincs tesztelhető elem"; 
$LANG['rulesengine'][100]="Cache információk"; 
$LANG['rulesengine'][102]="Szabály neve"; 
$LANG['rulesengine'][103]="Objektumok a cache-ben"; 
$LANG['rulesengine'][104]="Eredeti érték"; 
$LANG['rulesengine'][105]="Módosított érték"; 
$LANG['rulesengine'][106]="Változatlan"; 
$LANG['rulesengine'][107]="Inaktív"; 
$LANG['rulesengine'][108]="eredeti"; 
$LANG['rulesengine'][110]="Jogok hozzárendelése"; 
$LANG['rulesengine'][111]="Szervezet hozzárendelés"; 
$LANG['rulesengine'][112]="Jogok és szervezetek összerendelése"; 
$LANG['rulesengine'][120]="A motor megáll az első szabály után"; 
$LANG['rulesengine'][121]="A motor minden szabályt feldolgoz"; 
$LANG['rulesengine'][122]="A motor átadja egy szabály eredményét a következőknek"; 
$LANG['rulesengine'][130]="Szervezet LDAP-ból"; 
$LANG['rulesengine'][131]="Szervezet címkéből (TAG)"; 
$LANG['rulesengine'][132]="Sikertelen import"; 
$LANG['rulesengine'][133]="Szervezet domain"; 
$LANG['rulesengine'][134]="E-mail visszautasítás (válasz nélkül)"; 
$LANG['rulesengine'][135]="E-mail visszautasítás (email válasszal)"; 
$LANG['rulesengine'][138]="LDAP feltételek"; 
$LANG['rulesengine'][140]="Új feltétel"; 
$LANG['rulesengine'][142]="Nem importált levelek listája"; 
$LANG['rulesengine'][144]="Felhasználó profilján alapuló szervezet"; 
$LANG['rulesengine'][145]="Egyszerű profilú felhasználó"; 
$LANG['rulesengine'][146]="A következő profilhoz tartozó felhasználó"; 
$LANG['rulesengine'][147]="Egyetlen profilhoz tartozó felhasználó"; 
$LANG['rulesengine'][148]="A levelezőtartomány ismert"; 
$LANG['rulesengine'][150]="A szabályok ki vannak kapcsolva."; 

$LANG['search'][0]="Keresés"; 
$LANG['search'][1]="mindegyik"; 
$LANG['search'][2]="tartalmaz"; 
$LANG['search'][4]="rendezés"; 
$LANG['search'][8]="Kezdő dátum"; 
$LANG['search'][9]="Záró dátum"; 
$LANG['search'][10]=""; 
$LANG['search'][11]="Tétel tartalmaz"; 
$LANG['search'][12]="Befejező dátuma van"; 
$LANG['search'][15]="Nincs tétel"; 
$LANG['search'][16]="Legalább"; 
$LANG['search'][17]="Új keresési feltétel"; 
$LANG['search'][18]="Keresési feltétel törlése"; 
$LANG['search'][19]="Új keresési feltétel"; 
$LANG['search'][20]="Keresési feltétel törlése"; 

$LANG['setup'][0]="Legördülő listák"; 
$LANG['setup'][2]="Új GLPI felhasználó"; 
$LANG['setup'][3]="LDAP kapcsolat"; 
$LANG['setup'][4]="Számítógép típusok"; 
$LANG['setup'][5]="Operációs rendszerek"; 
$LANG['setup'][6]="Megszemélyesítés"; 
$LANG['setup'][9]="Hálózati csatolók"; 
$LANG['setup'][10]="Utónevek cseréje a vezetéknévvel"; 
$LANG['setup'][14]="E-mail"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Jelszó"; 
$LANG['setup'][20]="Jelszó megerősítése"; 
$LANG['setup'][21]="Hiba : a jelszavak nem egyeznek meg"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Privát követése alapértelmezésként"; 
$LANG['setup'][40]="Privát feladatok alapértelmezetten"; 
$LANG['setup'][41]="Válassz nyelvet"; 
$LANG['setup'][42]="Hálózat típusok"; 
$LANG['setup'][43]="Nyomtató típusok"; 
$LANG['setup'][44]="Monitor típusok"; 
$LANG['setup'][45]="Ház típus"; 
$LANG['setup'][46]="Alapértelmezett érték"; 
$LANG['setup'][47]="Alapértelmezett grafikon típus"; 
$LANG['setup'][48]="Alapértelmezett értékek"; 
$LANG['setup'][62]="Válassza ki a beállítandó kategóriát"; 
$LANG['setup'][63]="Figyelem, egy vagy több tételben használt fejlécet fogsz eltávolítani"; 
$LANG['setup'][64]="Ha jóváhagyod a tételek törlését ezzel a fejléccel, az előírt mezők üresek lesznek"; 
$LANG['setup'][65]="Lecserélheted a fejléc összes eseményét is egy másikkal"; 
$LANG['setup'][67]="Külső hitelesítés"; 
$LANG['setup'][69]="Eszközök típusai"; 
$LANG['setup'][70]="Általános beállítások"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Fali csatlakozó"; 
$LANG['setup'][74]="Nem törölhetsz, mert almappákat tartalmaz"; 
$LANG['setup'][75]="A következő fia"; 
$LANG['setup'][79]="Bejelentések kategorizálása"; 
$LANG['setup'][80]="Partner típusa"; 
$LANG['setup'][81]="Dokumentum fejléc"; 
$LANG['setup'][82]="Kapcsolat típusa"; 
$LANG['setup'][83]="Tétel állapota"; 
$LANG['setup'][84]="Patron típus"; 
$LANG['setup'][85]="Szerződés típusa"; 
$LANG['setup'][86]="RAM Típus"; 
$LANG['setup'][87]="Tudástár kategóriák"; 
$LANG['setup'][88]="Hálózat"; 
$LANG['setup'][89]="Domain"; 
$LANG['setup'][90]="VLAN-ok"; 
$LANG['setup'][91]="Számítógép modellek"; 
$LANG['setup'][92]="Kellék típus"; 
$LANG['setup'][93]="Interfészek (merevlemez, ...)"; 
$LANG['setup'][94]="Monitor modellek"; 
$LANG['setup'][95]="Hálózati modellek"; 
$LANG['setup'][96]="Nyomtató modellek"; 
$LANG['setup'][97]="Periféria modellek"; 
$LANG['setup'][98]="Feladat kategória"; 
$LANG['setup'][99]="Épület száma"; 
$LANG['setup'][100]="Szobaszám"; 
$LANG['setup'][101]="Automatikus műveletek max. száma (CLI)"; 
$LANG['setup'][102]="Naplózási szint"; 
$LANG['setup'][103]="1- Kritikus (csak a bejelentkezési hibákat)"; 
$LANG['setup'][104]="2- Súlyos (nem használt)"; 
$LANG['setup'][105]="3- Fontos (sikeres belépések)"; 
$LANG['setup'][106]="4- Jelentős (hozzáadás, törlés, követés)"; 
$LANG['setup'][107]="5- Teljes"; 
$LANG['setup'][109]="Naplók megőrzése (napokban, 0=végtelen)"; 
$LANG['setup'][110]="Mutassa az új bejelentéseket bejelentkezéskor"; 
$LANG['setup'][111]="Keresési eredmények egy oldalon"; 
$LANG['setup'][112]="Elemek maximuma legördülő listákban"; 
$LANG['setup'][113]="Alapértelmezett nyelv"; 
$LANG['setup'][114]="Prioritás színek"; 
$LANG['setup'][115]="Alapértelmezett riasztási küszöb patronokhoz és kellékekhez"; 
$LANG['setup'][116]="Bejelentések automatikus felelőshöz rendelése"; 
$LANG['setup'][117]="Tudásbázis megtekintése névtelenül"; 
$LANG['setup'][118]="Bejelentkező képernyő szövege"; 
$LANG['setup'][119]="Megjelenítés beállításai"; 
$LANG['setup'][120]="Ajax használata legördülőkben és szöveges mezőkben"; 
$LANG['setup'][121]="Ajax helyettesítő karakter"; 
$LANG['setup'][122]="Legördülőkben megjelenő elemek száma"; 
$LANG['setup'][123]="Ajax kikapcsolása, ha a tételek száma kevesebb, mint (0=soha)"; 
$LANG['setup'][124]="Külső hitelesítési forrásból származó felhasználó automatikus felvétele"; 
$LANG['setup'][125]="... külső forrásból"; 
$LANG['setup'][126]="Felhasználó automatikus hozzáadása külső forrásból"; 
$LANG['setup'][127]="Szövegmezők automatikus kiegészítése Ajax-al"; 
$LANG['setup'][128]="Dátumformátum"; 
$LANG['setup'][129]="GLPI ID megjelenítése"; 
$LANG['setup'][130]="Következő/előző tételek"; 
$LANG['setup'][132]="Lista megnyitása"; 
$LANG['setup'][133]="OCSNG mód bekapcsolása"; 
$LANG['setup'][134]="OCSNG mód"; 
$LANG['setup'][135]="Normál"; 
$LANG['setup'][136]="Fordítás"; 
$LANG['setup'][137]="Hibakeresés"; 
$LANG['setup'][138]="GLPI a következő módban"; 
$LANG['setup'][139]="Általános"; 
$LANG['setup'][140]="Típusok"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dinamikus kijelzés (ajax)"; 
$LANG['setup'][148]="Időközök"; 
$LANG['setup'][149]="Tizedes helyek száma"; 
$LANG['setup'][150]="Számformátum"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (nem anonimokhoz)"; 
$LANG['setup'][156]="Jelszó (hitelesített kapcsolódáshoz)"; 
$LANG['setup'][157]="Az LDAP bővítmény nincs telepítve a PHP-ben"; 
$LANG['setup'][158]="Nem lehet használni az LDAP-ot"; 
$LANG['setup'][159]="Kapcsolat szűrő"; 
$LANG['setup'][162]="IMAP/POP konfiguráció"; 
$LANG['setup'][164]="IMAP/POP gépnév <br>(felhasználói e-mail címek login@gépnév formátumúak)"; 
$LANG['setup'][165]="A PHP-ben nincs IMAP támogatás"; 
$LANG['setup'][166]="Nem lehet használni az IMAP/POP-ot külső forrásként"; 
$LANG['setup'][167]="GLPI/LDAP hivatkozások"; 
$LANG['setup'][168]="Kapcsolat beállításai"; 
$LANG['setup'][169]="E-mail mappa (opcionális, általában INBOX)"; 
$LANG['setup'][170]="Eredmény kapcsolat paraméter"; 
$LANG['setup'][171]="Port (opcionális)"; 
$LANG['setup'][172]="LDAP port (alap=389)"; 
$LANG['setup'][174]="CAS Host"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Főkönyvtár (opcionális)"; 
$LANG['setup'][177]="CAS konfiguráció"; 
$LANG['setup'][178]="Nincs telepítve a CURL vagy a DOMXML bővítmény a PHP feldolgozóba"; 
$LANG['setup'][179]="Nem lehet a CAS-t használni külső kapcsolatként"; 
$LANG['setup'][180]="TLS használata"; 
$LANG['setup'][181]="ldap_start_tls nem létezik"; 
$LANG['setup'][182]="Kilépéskori URL"; 
$LANG['setup'][185]="Logok több fájlba"; 
$LANG['setup'][186]="Időzóna"; 
$LANG['setup'][190]="x509 kulcs"; 
$LANG['setup'][191]="e-mail attribútum x509-hez"; 
$LANG['setup'][192]="Bekapcsolva"; 
$LANG['setup'][193]="A login-t tartalmazó mező a _SERVER tömbben"; 
$LANG['setup'][194]="Bővített információk lekérése LDAP-ból"; 
$LANG['setup'][195]="Állapot megtartása"; 
$LANG['setup'][196]="Állapot törlése"; 
$LANG['setup'][197]="Számítógép állapot másolása"; 
$LANG['setup'][198]="Állapot beállítása"; 
$LANG['setup'][199]="Domain eltávolítása a login@domain nevekből"; 
$LANG['setup'][200]="Végtelen"; 
$LANG['setup'][201]="Funkció beállítások"; 
$LANG['setup'][202]="E-mail értesítők használata"; 
$LANG['setup'][203]="Karbantartó e-mail címe"; 
$LANG['setup'][204]="E-mail aláírás"; 
$LANG['setup'][205]="A levél el lett küldve az adminisztrátornak"; 
$LANG['setup'][206]="A levélküldés az adminisztrátorhoz nem sikerült"; 
$LANG['setup'][207]="Adminisztrátor válaszcíme (ha szükséges)"; 
$LANG['setup'][217]="A mail funkció ismeretlen vagy nincs bekapcsolva"; 
$LANG['setup'][218]="Nem lehet beállítani az e-mail követeket"; 
$LANG['setup'][219]="Névtelen bejelentések beküldése engedélyezett"; 
$LANG['setup'][221]="Pénzügyi év kezdete (nap és hónap)"; 
$LANG['setup'][223]="Időzítések korlátja a tervezésben"; 
$LANG['setup'][227]="Használt alap URL"; 
$LANG['setup'][228]="Login mező"; 
$LANG['setup'][229]="Teszt levél küldése az adminisztrátornak"; 
$LANG['setup'][231]="SMTP használata levélküldéshez"; 
$LANG['setup'][232]="SMTP gépnév"; 
$LANG['setup'][234]="SMTP felhasználónév"; 
$LANG['setup'][235]="SMTP jelszó"; 
$LANG['setup'][236]="A bejelentés korábbi felelőse"; 
$LANG['setup'][237]="Adminisztrátor"; 
$LANG['setup'][239]="A bejelentés felelőse"; 
$LANG['setup'][240]="Értesítés beállításai"; 
$LANG['setup'][241]="Nincs személyes kritérium. Létrehozzam a személyes paramétereket ?"; 
$LANG['setup'][242]="Riasztások beállításai"; 
$LANG['setup'][243]="Kellékek riasztásai"; 
$LANG['setup'][244]="Patronok riasztásai"; 
$LANG['setup'][245]="Emlékeztetők gyakorisága"; 
$LANG['setup'][246]="Szerződések riasztásai"; 
$LANG['setup'][247]="Pénzügyi információk riasztásai"; 
$LANG['setup'][248]="Bejelentéssel megbízott csoport"; 
$LANG['setup'][249]="Kérelmező csoport"; 
$LANG['setup'][250]="Alapértelmezett keresési mezők"; 
$LANG['setup'][252]="Válassz alapértelmezett tételt"; 
$LANG['setup'][253]="Szűrő a csoportokban kereséshez"; 
$LANG['setup'][254]="Keresés típus"; 
$LANG['setup'][255]="Csoport attribútum"; 
$LANG['setup'][256]="Felhasználókban"; 
$LANG['setup'][257]="Csoportokban"; 
$LANG['setup'][258]="Felhasználók és csoportok"; 
$LANG['setup'][259]="Csoportokhoz tartozik"; 
$LANG['setup'][260]="A csoportokat tartalmazó attribútum"; 
$LANG['setup'][261]="Csoport DN"; 
$LANG['setup'][262]="Keresés DN"; 
$LANG['setup'][263]="Keresési szűrő felhasználókra"; 
$LANG['setup'][264]="Riasztások licenc lejáratakor"; 
$LANG['setup'][271]="Monitorkezelés korlátozása"; 
$LANG['setup'][272]="Eszközkezelés korlátozása"; 
$LANG['setup'][273]="Telefonkezelés korlátozása"; 
$LANG['setup'][274]="hozzáadás kézzel"; 
$LANG['setup'][275]="Nyomtatókezelés korlátozása"; 
$LANG['setup'][280]="Géphez kapcsolódó elemek automatikus frissítése"; 
$LANG['setup'][281]="Viselkedés kapcsolódáskor/módosításkor"; 
$LANG['setup'][282]="Viselkedés lekapcsoláskor"; 
$LANG['setup'][283]="Másolás"; 
$LANG['setup'][284]="Törlés"; 
$LANG['setup'][285]="Ne másolja"; 
$LANG['setup'][286]="Ne törölje"; 
$LANG['setup'][300]="Új verzió ellenőrzése"; 
$LANG['setup'][301]="Az alábbi új verzió érhető el:"; 
$LANG['setup'][302]="Elérhető a GLPI weboldaláról: <a href='http://glpi-project.org' target='_blank'>http://glpi-project.org</a>"; 
$LANG['setup'][303]="A legújabb verzió működik."; 
$LANG['setup'][304]="A frissítés ellenőrzése nem sikerült"; 
$LANG['setup'][305]="Minden nap"; 
$LANG['setup'][306]="Frissítés keresése"; 
$LANG['setup'][307]="Soha"; 
$LANG['setup'][308]="Minden héten"; 
$LANG['setup'][309]="Minden hónapban"; 
$LANG['setup'][310]="Sikertelen kapcsolódás a helyhez"; 
$LANG['setup'][311]="A proxy-hoz kapcsolódás sikertelen"; 
$LANG['setup'][312]="Nincs elérhető adat a webhelyen"; 
$LANG['setup'][313]="Légy óvatos : nincs alapértelmezett érték"; 
$LANG['setup'][350]="Hivatkozás a jegy létrehozására"; 
$LANG['setup'][351]="Minden elem"; 
$LANG['setup'][352]="Bejelentéssel kapcsolható tételek"; 
$LANG['setup'][360]="Automata mezők (*-al jelölve)"; 
$LANG['setup'][400]="Proxy beállítások"; 
$LANG['setup'][407]="Helpdesk súgó hivatkozás"; 
$LANG['setup'][408]="Standard felület súgó hivatkozás"; 
$LANG['setup'][409]="Bejelentéshez csatolt dokumentum alapértelmezett fejléce"; 
$LANG['setup'][503]="Telefon típusok"; 
$LANG['setup'][504]="Telefon típusok"; 
$LANG['setup'][505]="Telefon tápegység típusa"; 
$LANG['setup'][601]="LDAP érték"; 
$LANG['setup'][602]="Kapcsolódás OCS adatbázishoz"; 
$LANG['setup'][603]="Új felhasználó"; 
$LANG['setup'][604]="Csoporthoz rendelés"; 
$LANG['setup'][606]="A felhasználó már létezik."; 
$LANG['setup'][607]="Profilhoz rendelés"; 
$LANG['setup'][608]="Alapértelmezés szerint a szoftverek láthatók a helpdesk modulban"; 
$LANG['setup'][609]="Nem sikerült a felvitel, az OCS szerver már létezik."; 
$LANG['setup'][610]="Bejelentés címe kötelező"; 
$LANG['setup'][611]="Bejelentés tartalma kötelező"; 
$LANG['setup'][612]="Bejelentés kategóriája kötelező"; 
$LANG['setup'][613]="Új LDAP felhasználó jogok nélkül"; 
$LANG['setup'][614]="A login frissítése sikertelen. A felhasználó már létezik."; 
$LANG['setup'][615]="Bejelentések életciklusa"; 
$LANG['setup'][616]="Tól-ig"; 
$LANG['setup'][620]="Hivatkozás"; 
$LANG['setup'][621]="Keresési szűrő szervezetekre"; 
$LANG['setup'][622]="Szervezetet azonosító attribútum"; 
$LANG['setup'][623]="Szervezetek importja LDAP-ból"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail szerver"; 
$LANG['setup'][661]="Riasztások beállítása lehetetlen, engedélyezze az e-mail figyelést"; 
$LANG['setup'][703]="Általános"; 
$LANG['setup'][704]="Értesítések"; 
$LANG['setup'][707]="Foglalások riasztásai"; 
$LANG['setup'][708]="Riasztások megoldatlan bejelentésekre"; 
$LANG['setup'][720]="Rendszer-információk"; 
$LANG['setup'][721]="Telepítési és beállítási rendszer-információ"; 
$LANG['setup'][722]="Másol/beilleszt a támogatási kérelemben"; 
$LANG['setup'][731]="Globális konfigurációs érték"; 
$LANG['setup'][732]="Email domain"; 
$LANG['setup'][800]="Mysql replikálás"; 
$LANG['setup'][801]="Replika engedélyezés"; 
$LANG['setup'][802]="Adatbázis"; 
$LANG['setup'][803]="Mester és szolga közötti különbség"; 
$LANG['setup'][806]="Max késleltetés mester és szolga között (percben)"; 
$LANG['setup'][807]="A szolga nincs szinkronban. Különbségek :"; 
$LANG['setup'][808]="A szolga adatbázis nincs szinkronban!"; 
$LANG['setup'][809]="Mysql replika: csak olvasható"; 
$LANG['setup'][810]="Mysql replikáció deszinkronizálása"; 

$LANG['software'][1]="Vásárolt verzió"; 
$LANG['software'][2]="Használt verzió"; 
$LANG['software'][3]="Nem telepített érintett licenszek"; 
$LANG['software'][4]="Korlátlan"; 
$LANG['software'][5]="Verziók"; 
$LANG['software'][6]="Kiadó"; 
$LANG['software'][7]="Új verzió"; 
$LANG['software'][8]="Új licenc"; 
$LANG['software'][11]="Licencek"; 
$LANG['software'][17]="Telepített szoftver"; 
$LANG['software'][19]="Telepítve"; 
$LANG['software'][20]="Maradék"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Módosítás"; 
$LANG['software'][30]="Licencek típusa"; 
$LANG['software'][32]="Lejárat"; 
$LANG['software'][44]="Szoftver telepítés"; 
$LANG['software'][45]="Telepítés törlése"; 
$LANG['software'][46]="Látható a Helpdesk-ben"; 
$LANG['software'][47]="Hozzáfűzés"; 
$LANG['software'][48]="Összefűz"; 
$LANG['software'][49]="A szoftver lomtárba helyezése összefűzés után"; 
$LANG['software'][50]="Hozzárendelve a számítógéphez"; 
$LANG['software'][51]="A számnak 1-nek kell lennie a működéshez"; 

$LANG['softwarecategories'][2]="Gyűjtés nélkül"; 
$LANG['softwarecategories'][3]="Kategória nélküli szoftverek kibontása"; 
$LANG['softwarecategories'][4]="Kategorizált szoftverek kibontása"; 
$LANG['softwarecategories'][5]="Szoftverkategória"; 

$LANG['state'][0]="Állapot"; 
$LANG['state'][6]="Tétel típus"; 
$LANG['state'][7]="Nincs tétel"; 
$LANG['state'][11]="Szintetika"; 

$LANG['stats'][0]="Válassz statisztikát"; 
$LANG['stats'][1]="Teljes"; 
$LANG['stats'][2]="Nincs megjeleníthető elem"; 
$LANG['stats'][3]="Típusonként"; 
$LANG['stats'][5]="Bejelentések száma"; 
$LANG['stats'][6]="Átlagos megoldási késés"; 
$LANG['stats'][7]="Grafikonok megnézése"; 
$LANG['stats'][11]="Megoldott bejelentések száma"; 
$LANG['stats'][13]="Bejelentések száma"; 
$LANG['stats'][15]="Átlagos megoldási idő"; 
$LANG['stats'][16]="Technikus neve"; 
$LANG['stats'][20]="Felhasználónév"; 
$LANG['stats'][23]="Nincs elérhető statisztika"; 
$LANG['stats'][25]="Bejelentés átlagos átfutási ideje"; 
$LANG['stats'][27]="Bejelentés valós összideje"; 
$LANG['stats'][30]="Átlagos reakcióidő"; 
$LANG['stats'][31]="Nap"; 
$LANG['stats'][33]="perc"; 
$LANG['stats'][34]="Mp"; 
$LANG['stats'][35]="Bejelentés(ek)"; 
$LANG['stats'][44]="Cégnév"; 
$LANG['stats'][45]="Hardverenként"; 
$LANG['stats'][47]="Bejelentőnként"; 
$LANG['stats'][48]="(hozzárendelve)"; 
$LANG['stats'][49]="(intézkedések)"; 

$LANG['title'][5]="Tudásbázis"; 
$LANG['title'][6]="Hálózat"; 
$LANG['title'][9]="Tétel állapotok"; 
$LANG['title'][10]="Bejelentés követése"; 
$LANG['title'][13]="Felhasználói információk"; 
$LANG['title'][14]="Külső hitelesítési források"; 
$LANG['title'][24]="HelpDesk"; 
$LANG['title'][26]="Fő"; 
$LANG['title'][27]="Kapcsolatok"; 
$LANG['title'][28]="Bejelentések"; 
$LANG['title'][30]="Alkatrészek"; 
$LANG['title'][33]="Külső hivatkozások"; 
$LANG['title'][34]="Hivatkozások"; 
$LANG['title'][37]="Jegyzetek"; 
$LANG['title'][38]="Történet"; 
$LANG['title'][40]="Nyilvános és személyes jegyzetek"; 
$LANG['title'][42]="Alapos módosítás"; 
$LANG['title'][43]="Registry"; 

$LANG['tracking'][1]="Saját eszközök"; 
$LANG['tracking'][2]="Vagy teljes keresés"; 
$LANG['tracking'][3]="Érvénytelen dátum. Frissítés megszakítva."; 
$LANG['tracking'][4]="Nincs beállítva a sürgősség, javítani szükséges."; 
$LANG['tracking'][8]="Nincs leírás, próbáld újra"; 
$LANG['tracking'][9]="Helpdeskben a kérések alapértelmezett forrása"; 
$LANG['tracking'][10]="Alapértelmezett kérelem forrás e-mail érkeztetőkhöz"; 
$LANG['tracking'][24]="Bejelentés dokumentálása"; 
$LANG['tracking'][29]="Szám"; 
$LANG['tracking'][30]="Új"; 
$LANG['tracking'][31]="Feldolgozás alatt (kiadva)"; 
$LANG['tracking'][32]="Feldolgozás alatt (tervezett)"; 
$LANG['tracking'][34]="Közvetlen"; 
$LANG['tracking'][35]="Írásos"; 
$LANG['tracking'][37]="Bejelentések megtartása hardverek törlésekor"; 
$LANG['tracking'][38]="E-mail elküldve"; 
$LANG['tracking'][39]="Látható a helpdesk felületen"; 

$LANG['transfer'][1]="Áthelyezés"; 
$LANG['transfer'][3]="Ha nincs használatban"; 
$LANG['transfer'][4]="Áthelyezendők listájának kiürítése"; 
$LANG['transfer'][5]="Folytathatod az elemek hozzáadását vagy indíthatod az áthelyezést"; 
$LANG['transfer'][6]="Készíts mentést az áthelyezés előtt"; 
$LANG['transfer'][7]="Áthelyezendő elemek"; 
$LANG['transfer'][8]="Áthelyezés módja"; 

$LANG['update'][88]="A telepített adatbázis verziója nem kompatibilis a programmal, frissítés szükséges."; 
$LANG['update'][89]="Próbáljon újabb verzióhoz tervezett adatbázist használni."; 
$LANG['update'][90]="Hiba az adatbázis frissítésekor"; 
$LANG['update'][91]="Figyelem !"; 
$LANG['update'][92]="A következő GLPI adatbázis lesz frissítve:"; 
$LANG['update'][93]="A kapcsolódás az adatbázishoz sikerült."; 
$LANG['update'][94]="A frissítés sikeres, az adatbázis friss"; 
$LANG['update'][95]="Az adatbázishoz nem sikerült csatlakozni, ellenőrizze a beállításokat a config_db.php fájlban"; 
$LANG['update'][96]="Most minden adminisztrátornak super-admin joga van. Az új felhasználótípus is létrejött."; 
$LANG['update'][105]="Nem lehet így elérni a frissítést !!"; 
$LANG['update'][106]="Vissza a GLPI-hez"; 
$LANG['update'][107]="El kell indítanod az adatbázis tartalmának frissítését"; 
$LANG['update'][130]="Helyek frissítése"; 
$LANG['update'][131]="Az új felépítés hierarchikus"; 
$LANG['update'][132]="Ha használt elválasztó karaktert, beállíthatja az új hierarchia automatikus generálásához"; 
$LANG['update'][133]="Meg kell adnod a helyek gyökerét, ami minden létrehozott helyet tartalmazni fog."; 
$LANG['update'][134]="Elválasztó karakter"; 
$LANG['update'][135]="Fő hely"; 
$LANG['update'][136]="Ez az új hierarchia. Ha rendben, érvényesítheted."; 
$LANG['update'][137]="Új hierarchia"; 
$LANG['update'][138]="Aktuális helyek"; 
$LANG['update'][139]="Adattáblák optimalizálása"; 
$LANG['update'][140]="Indexelés"; 
$LANG['update'][141]="Adatbázis séma módosítása"; 
$LANG['update'][142]="Adat migráció"; 

$LANG['users'][1]="Cím"; 
$LANG['users'][2]="Kategória"; 

$LANG['validation'][0]="Érvényesítés"; 
$LANG['validation'][1]="Érvényesítési kérelem küldése"; 
$LANG['validation'][2]="Állapot"; 
$LANG['validation'][3]="Kérelem dátuma"; 
$LANG['validation'][4]="Érvényesítés dátuma"; 
$LANG['validation'][5]="Kérelem kommentálása"; 
$LANG['validation'][6]="Érvényesség kommentálása"; 
$LANG['validation'][7]="Bejelentés érvényesítései"; 
$LANG['validation'][9]="Érvényesítésre vár"; 
$LANG['validation'][10]="Visszautasított"; 
$LANG['validation'][11]="Elfogadva"; 
$LANG['validation'][12]="Nem képezi jóváhagyás tárgyát"; 
$LANG['validation'][13]="Érvényesítés kérelem elküldve"; 
$LANG['validation'][15]="Bejelentés érvényesítésre vár"; 
$LANG['validation'][16]="Elfogadás esetén nem kötelező"; 
$LANG['validation'][18]="Érvényesítés kérelmező"; 
$LANG['validation'][19]="Érvényesítés elfogadva"; 
$LANG['validation'][20]="Érvényesítés megtagadva"; 
$LANG['validation'][21]="Érvényesítő felhasználó"; 
$LANG['validation'][23]="A kiválasztott felhasználónak nincs e-mail címe. A kérelem létrejött, de levelet nem sikerült küldeni."; 
$LANG['validation'][25]="Global validation status"; 
$LANG['validation'][26]="Érvényesítési kérelem"; 
$LANG['validation'][27]="Érvényesítési kérelem elküldve"; 
$LANG['validation'][28]="Érvényesítési kérelem állapota"; 
$LANG['validation'][29]="Ha nem értesz egyet, indokolnod kell"; 
$LANG['validation'][30]="Érvényesítési kérelem eltávolítása"; 
$LANG['validation'][31]="Érvényesítés kérelem frissítése"; 
$LANG['validation'][32]="Válasz érkezett érvényesítési kérelemre"; 
$LANG['validation'][33]="A bejelentés jóváhagyásra vár"; 
?>